# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vdp/pipeline/v1beta/component_definition.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from vdp.pipeline.v1beta import common_pb2 as vdp_dot_pipeline_dot_v1beta_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.vdp/pipeline/v1beta/component_definition.proto\x12\x13vdp.pipeline.v1beta\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a vdp/pipeline/v1beta/common.proto\"\xf0\n\n\x13\x43omponentDefinition\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x04name\x12\x16\n\x03uid\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid\x12\x14\n\x02id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x05R\x02id\x12\x1a\n\x05title\x18\x04 \x01(\tB\x04\xe2\x41\x01\x03R\x05title\x12\x31\n\x11\x64ocumentation_url\x18\x05 \x01(\tB\x04\xe2\x41\x01\x03R\x10\x64ocumentationUrl\x12\x18\n\x04icon\x18\x06 \x01(\tB\x04\xe2\x41\x01\x03R\x04icon\x12G\n\x04spec\x18\x07 \x01(\x0b\x32-.vdp.pipeline.v1beta.ComponentDefinition.SpecB\x04\xe2\x41\x01\x03R\x04spec\x12<\n\x04type\x18\x08 \x01(\x0e\x32\".vdp.pipeline.v1beta.ComponentTypeB\x04\xe2\x41\x01\x03R\x04type\x12\"\n\ttombstone\x18\t \x01(\x08\x42\x04\xe2\x41\x01\x03R\ttombstone\x12\x1c\n\x06public\x18\n \x01(\x08\x42\x04\xe2\x41\x01\x03R\x06public\x12\x1c\n\x06\x63ustom\x18\x0b \x01(\x08\x42\x04\xe2\x41\x01\x03R\x06\x63ustom\x12\x1c\n\x06vendor\x18\x0c \x01(\tB\x04\xe2\x41\x01\x03R\x06vendor\x12J\n\x11vendor_attributes\x18\r \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x03R\x10vendorAttributes\x12#\n\nsource_url\x18\x0e \x01(\tB\x04\xe2\x41\x01\x03R\tsourceUrl\x12\x1e\n\x07version\x18\x0f \x01(\tB\x04\xe2\x41\x01\x03R\x07version\x12>\n\x05tasks\x18\x10 \x03(\x0b\x32\".vdp.pipeline.v1beta.ComponentTaskB\x04\xe2\x41\x01\x03R\x05tasks\x12&\n\x0b\x64\x65scription\x18\x11 \x01(\tB\x04\xe2\x41\x01\x03R\x0b\x64\x65scription\x12`\n\rrelease_stage\x18\x12 \x01(\x0e\x32\x35.vdp.pipeline.v1beta.ComponentDefinition.ReleaseStageB\x04\xe2\x41\x01\x03R\x0creleaseStage\x1a\xcb\x02\n\x04Spec\x12V\n\x17\x63omponent_specification\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x02R\x16\x63omponentSpecification\x12|\n\x13\x64\x61ta_specifications\x18\x05 \x03(\x0b\x32\x45.vdp.pipeline.v1beta.ComponentDefinition.Spec.DataSpecificationsEntryB\x04\xe2\x41\x01\x02R\x12\x64\x61taSpecifications\x1am\n\x17\x44\x61taSpecificationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12<\n\x05value\x18\x02 \x01(\x0b\x32&.vdp.pipeline.v1beta.DataSpecificationR\x05value:\x02\x38\x01\";\n\x04View\x12\x14\n\x10VIEW_UNSPECIFIED\x10\x00\x12\x0e\n\nVIEW_BASIC\x10\x01\x12\r\n\tVIEW_FULL\x10\x02\"\xbc\x01\n\x0cReleaseStage\x12\x1d\n\x19RELEASE_STAGE_UNSPECIFIED\x10\x00\x12\'\n#RELEASE_STAGE_OPEN_FOR_CONTRIBUTION\x10\x01\x12\x1d\n\x19RELEASE_STAGE_COMING_SOON\x10\x02\x12\x17\n\x13RELEASE_STAGE_ALPHA\x10\x03\x12\x16\n\x12RELEASE_STAGE_BETA\x10\x04\x12\x14\n\x10RELEASE_STAGE_GA\x10\x05\"\x7f\n\x11\x44\x61taSpecification\x12\x33\n\x05input\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x03R\x05input\x12\x35\n\x06output\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x03R\x06output\"\xd5\x02\n\rConnectorSpec\x12V\n\x17\x63omponent_specification\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x02R\x16\x63omponentSpecification\x12q\n\x13\x64\x61ta_specifications\x18\x05 \x03(\x0b\x32:.vdp.pipeline.v1beta.ConnectorSpec.DataSpecificationsEntryB\x04\xe2\x41\x01\x02R\x12\x64\x61taSpecifications\x1am\n\x17\x44\x61taSpecificationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12<\n\x05value\x18\x02 \x01(\x0b\x32&.vdp.pipeline.v1beta.DataSpecificationR\x05value:\x02\x38\x01J\x04\x08\x02\x10\x03J\x04\x08\x04\x10\x05\"\x85\x07\n\x13\x43onnectorDefinition\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x04name\x12\x16\n\x03uid\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid\x12\x14\n\x02id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x05R\x02id\x12\x1a\n\x05title\x18\x04 \x01(\tB\x04\xe2\x41\x01\x03R\x05title\x12\x31\n\x11\x64ocumentation_url\x18\x05 \x01(\tB\x04\xe2\x41\x01\x03R\x10\x64ocumentationUrl\x12\x18\n\x04icon\x18\x06 \x01(\tB\x04\xe2\x41\x01\x03R\x04icon\x12<\n\x04spec\x18\x07 \x01(\x0b\x32\".vdp.pipeline.v1beta.ConnectorSpecB\x04\xe2\x41\x01\x03R\x04spec\x12<\n\x04type\x18\x08 \x01(\x0e\x32\".vdp.pipeline.v1beta.ConnectorTypeB\x04\xe2\x41\x01\x03R\x04type\x12\"\n\ttombstone\x18\t \x01(\x08\x42\x04\xe2\x41\x01\x03R\ttombstone\x12\x1c\n\x06public\x18\n \x01(\x08\x42\x04\xe2\x41\x01\x03R\x06public\x12\x1c\n\x06\x63ustom\x18\x0b \x01(\x08\x42\x04\xe2\x41\x01\x03R\x06\x63ustom\x12\x1c\n\x06vendor\x18\r \x01(\tB\x04\xe2\x41\x01\x03R\x06vendor\x12J\n\x11vendor_attributes\x18\x0e \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x03R\x10vendorAttributes\x12#\n\nsource_url\x18\x0f \x01(\tB\x04\xe2\x41\x01\x03R\tsourceUrl\x12\x1e\n\x07version\x18\x10 \x01(\tB\x04\xe2\x41\x01\x03R\x07version\x12>\n\x05tasks\x18\x11 \x03(\x0b\x32\".vdp.pipeline.v1beta.ComponentTaskB\x04\xe2\x41\x01\x03R\x05tasks\x12&\n\x0b\x64\x65scription\x18\x12 \x01(\tB\x04\xe2\x41\x01\x03R\x0b\x64\x65scription\x12`\n\rrelease_stage\x18\x13 \x01(\x0e\x32\x35.vdp.pipeline.v1beta.ComponentDefinition.ReleaseStageB\x04\xe2\x41\x01\x03R\x0creleaseStage:b\xea\x41_\n$api.instill.tech/ConnectorDefinition\x12\x1a\x63onnector-definitions/{id}\x12\x1b\x63onnector-definitions/{uid}J\x04\x08\x0c\x10\r\"\xcd\x02\n\x0cOperatorSpec\x12V\n\x17\x63omponent_specification\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x02R\x16\x63omponentSpecification\x12p\n\x13\x64\x61ta_specifications\x18\x03 \x03(\x0b\x32\x39.vdp.pipeline.v1beta.OperatorSpec.DataSpecificationsEntryB\x04\xe2\x41\x01\x02R\x12\x64\x61taSpecifications\x1am\n\x17\x44\x61taSpecificationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12<\n\x05value\x18\x02 \x01(\x0b\x32&.vdp.pipeline.v1beta.DataSpecificationR\x05value:\x02\x38\x01J\x04\x08\x02\x10\x03\"\xd8\x05\n\x12OperatorDefinition\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x04name\x12\x16\n\x03uid\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid\x12\x14\n\x02id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x05R\x02id\x12\x1a\n\x05title\x18\x04 \x01(\tB\x04\xe2\x41\x01\x03R\x05title\x12\x31\n\x11\x64ocumentation_url\x18\x05 \x01(\tB\x04\xe2\x41\x01\x03R\x10\x64ocumentationUrl\x12\x18\n\x04icon\x18\x06 \x01(\tB\x04\xe2\x41\x01\x03R\x04icon\x12;\n\x04spec\x18\x07 \x01(\x0b\x32!.vdp.pipeline.v1beta.OperatorSpecB\x04\xe2\x41\x01\x03R\x04spec\x12\"\n\ttombstone\x18\x08 \x01(\x08\x42\x04\xe2\x41\x01\x03R\ttombstone\x12\x1c\n\x06public\x18\t \x01(\x08\x42\x04\xe2\x41\x01\x03R\x06public\x12\x1c\n\x06\x63ustom\x18\n \x01(\x08\x42\x04\xe2\x41\x01\x03R\x06\x63ustom\x12#\n\nsource_url\x18\x0f \x01(\tB\x04\xe2\x41\x01\x03R\tsourceUrl\x12\x1e\n\x07version\x18\x10 \x01(\tB\x04\xe2\x41\x01\x03R\x07version\x12>\n\x05tasks\x18\x11 \x03(\x0b\x32\".vdp.pipeline.v1beta.ComponentTaskB\x04\xe2\x41\x01\x03R\x05tasks\x12&\n\x0b\x64\x65scription\x18\x12 \x01(\tB\x04\xe2\x41\x01\x03R\x0b\x64\x65scription\x12`\n\rrelease_stage\x18\x13 \x01(\x0e\x32\x35.vdp.pipeline.v1beta.ComponentDefinition.ReleaseStageB\x04\xe2\x41\x01\x03R\x0creleaseStage:_\xea\x41\\\n#api.instill.tech/OperatorDefinition\x12\x19operator-definitions/{id}\x12\x1aoperator-definitions/{uid}J\x04\x08\x0b\x10\x0c\"\x8a\x02\n\x1fListComponentDefinitionsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12L\n\x04view\x18\x03 \x01(\x0e\x32-.vdp.pipeline.v1beta.ComponentDefinition.ViewB\x04\xe2\x41\x01\x01H\x01R\x04view\x88\x01\x01\x12!\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x02R\x06\x66ilter\x88\x01\x01\x12\x1d\n\x04page\x18\x05 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x03R\x04page\x88\x01\x01\x42\x0c\n\n_page_sizeB\x07\n\x05_viewB\t\n\x07_filterB\x07\n\x05_pageJ\x04\x08\x02\x10\x03\"\xd7\x01\n ListComponentDefinitionsResponse\x12]\n\x15\x63omponent_definitions\x18\x01 \x03(\x0b\x32(.vdp.pipeline.v1beta.ComponentDefinitionR\x14\x63omponentDefinitions\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\x12\x1b\n\tpage_size\x18\x04 \x01(\x05R\x08pageSize\x12\x12\n\x04page\x18\x05 \x01(\x05R\x04pageJ\x04\x08\x02\x10\x03\"\x9b\x02\n\x1fListConnectorDefinitionsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12!\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x02R\x06\x66ilter\x88\x01\x01\x12L\n\x04view\x18\x05 \x01(\x0e\x32-.vdp.pipeline.v1beta.ComponentDefinition.ViewB\x04\xe2\x41\x01\x01H\x03R\x04view\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filterB\x07\n\x05_viewJ\x04\x08\x03\x10\x04\"\xc8\x01\n ListConnectorDefinitionsResponse\x12]\n\x15\x63onnector_definitions\x18\x01 \x03(\x0b\x32(.vdp.pipeline.v1beta.ConnectorDefinitionR\x14\x63onnectorDefinitions\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xe1\x01\n\x1dGetConnectorDefinitionRequest\x12\x63\n\x04name\x18\x01 \x01(\tBO\x92\x41\x1f\xca>\x1c\xfa\x02\x19\x63onnector_definition_name\xe2\x41\x01\x02\xfa\x41&\n$api.instill.tech/ConnectorDefinitionR\x04name\x12L\n\x04view\x18\x03 \x01(\x0e\x32-.vdp.pipeline.v1beta.ComponentDefinition.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_viewJ\x04\x08\x02\x10\x03\"}\n\x1eGetConnectorDefinitionResponse\x12[\n\x14\x63onnector_definition\x18\x01 \x01(\x0b\x32(.vdp.pipeline.v1beta.ConnectorDefinitionR\x13\x63onnectorDefinition\"\x9a\x02\n\x1eListOperatorDefinitionsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12!\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x02R\x06\x66ilter\x88\x01\x01\x12L\n\x04view\x18\x05 \x01(\x0e\x32-.vdp.pipeline.v1beta.ComponentDefinition.ViewB\x04\xe2\x41\x01\x01H\x03R\x04view\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filterB\x07\n\x05_viewJ\x04\x08\x03\x10\x04\"\xc4\x01\n\x1fListOperatorDefinitionsResponse\x12Z\n\x14operator_definitions\x18\x01 \x03(\x0b\x32\'.vdp.pipeline.v1beta.OperatorDefinitionR\x13operatorDefinitions\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xde\x01\n\x1cGetOperatorDefinitionRequest\x12\x61\n\x04name\x18\x01 \x01(\tBM\x92\x41\x1e\xca>\x1b\xfa\x02\x18operator_definition_name\xe2\x41\x01\x02\xfa\x41%\n#api.instill.tech/OperatorDefinitionR\x04name\x12L\n\x04view\x18\x03 \x01(\x0e\x32-.vdp.pipeline.v1beta.ComponentDefinition.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_viewJ\x04\x08\x02\x10\x03\"y\n\x1dGetOperatorDefinitionResponse\x12X\n\x13operator_definition\x18\x01 \x01(\x0b\x32\'.vdp.pipeline.v1beta.OperatorDefinitionR\x12operatorDefinition*\xca\x01\n\rConnectorType\x12\x1e\n\x1a\x43ONNECTOR_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11\x43ONNECTOR_TYPE_AI\x10\x03\x12\x17\n\x13\x43ONNECTOR_TYPE_DATA\x10\x05\x12\x1b\n\x17\x43ONNECTOR_TYPE_OPERATOR\x10\x06\x12\x1e\n\x1a\x43ONNECTOR_TYPE_APPLICATION\x10\x07\x12\x1a\n\x16\x43ONNECTOR_TYPE_GENERIC\x10\x08\"\x04\x08\x01\x10\x01\"\x04\x08\x02\x10\x02\"\x04\x08\x04\x10\x04\x42\xe7\x01\n\x17\x63om.vdp.pipeline.v1betaB\x18\x43omponentDefinitionProtoP\x01ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\xa2\x02\x03VPX\xaa\x02\x13Vdp.Pipeline.V1beta\xca\x02\x13Vdp\\Pipeline\\V1beta\xe2\x02\x1fVdp\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x15Vdp::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vdp.pipeline.v1beta.component_definition_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.vdp.pipeline.v1betaB\030ComponentDefinitionProtoP\001ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\242\002\003VPX\252\002\023Vdp.Pipeline.V1beta\312\002\023Vdp\\Pipeline\\V1beta\342\002\037Vdp\\Pipeline\\V1beta\\GPBMetadata\352\002\025Vdp::Pipeline::V1beta'
  _COMPONENTDEFINITION_SPEC_DATASPECIFICATIONSENTRY._options = None
  _COMPONENTDEFINITION_SPEC_DATASPECIFICATIONSENTRY._serialized_options = b'8\001'
  _COMPONENTDEFINITION_SPEC.fields_by_name['component_specification']._options = None
  _COMPONENTDEFINITION_SPEC.fields_by_name['component_specification']._serialized_options = b'\342A\001\002'
  _COMPONENTDEFINITION_SPEC.fields_by_name['data_specifications']._options = None
  _COMPONENTDEFINITION_SPEC.fields_by_name['data_specifications']._serialized_options = b'\342A\001\002'
  _COMPONENTDEFINITION.fields_by_name['name']._options = None
  _COMPONENTDEFINITION.fields_by_name['name']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['uid']._options = None
  _COMPONENTDEFINITION.fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['id']._options = None
  _COMPONENTDEFINITION.fields_by_name['id']._serialized_options = b'\342A\001\005'
  _COMPONENTDEFINITION.fields_by_name['title']._options = None
  _COMPONENTDEFINITION.fields_by_name['title']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['documentation_url']._options = None
  _COMPONENTDEFINITION.fields_by_name['documentation_url']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['icon']._options = None
  _COMPONENTDEFINITION.fields_by_name['icon']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['spec']._options = None
  _COMPONENTDEFINITION.fields_by_name['spec']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['type']._options = None
  _COMPONENTDEFINITION.fields_by_name['type']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['tombstone']._options = None
  _COMPONENTDEFINITION.fields_by_name['tombstone']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['public']._options = None
  _COMPONENTDEFINITION.fields_by_name['public']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['custom']._options = None
  _COMPONENTDEFINITION.fields_by_name['custom']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['vendor']._options = None
  _COMPONENTDEFINITION.fields_by_name['vendor']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['vendor_attributes']._options = None
  _COMPONENTDEFINITION.fields_by_name['vendor_attributes']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['source_url']._options = None
  _COMPONENTDEFINITION.fields_by_name['source_url']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['version']._options = None
  _COMPONENTDEFINITION.fields_by_name['version']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['tasks']._options = None
  _COMPONENTDEFINITION.fields_by_name['tasks']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['description']._options = None
  _COMPONENTDEFINITION.fields_by_name['description']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['release_stage']._options = None
  _COMPONENTDEFINITION.fields_by_name['release_stage']._serialized_options = b'\342A\001\003'
  _DATASPECIFICATION.fields_by_name['input']._options = None
  _DATASPECIFICATION.fields_by_name['input']._serialized_options = b'\342A\001\003'
  _DATASPECIFICATION.fields_by_name['output']._options = None
  _DATASPECIFICATION.fields_by_name['output']._serialized_options = b'\342A\001\003'
  _CONNECTORSPEC_DATASPECIFICATIONSENTRY._options = None
  _CONNECTORSPEC_DATASPECIFICATIONSENTRY._serialized_options = b'8\001'
  _CONNECTORSPEC.fields_by_name['component_specification']._options = None
  _CONNECTORSPEC.fields_by_name['component_specification']._serialized_options = b'\342A\001\002'
  _CONNECTORSPEC.fields_by_name['data_specifications']._options = None
  _CONNECTORSPEC.fields_by_name['data_specifications']._serialized_options = b'\342A\001\002'
  _CONNECTORDEFINITION.fields_by_name['name']._options = None
  _CONNECTORDEFINITION.fields_by_name['name']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['uid']._options = None
  _CONNECTORDEFINITION.fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['id']._options = None
  _CONNECTORDEFINITION.fields_by_name['id']._serialized_options = b'\342A\001\005'
  _CONNECTORDEFINITION.fields_by_name['title']._options = None
  _CONNECTORDEFINITION.fields_by_name['title']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['documentation_url']._options = None
  _CONNECTORDEFINITION.fields_by_name['documentation_url']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['icon']._options = None
  _CONNECTORDEFINITION.fields_by_name['icon']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['spec']._options = None
  _CONNECTORDEFINITION.fields_by_name['spec']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['type']._options = None
  _CONNECTORDEFINITION.fields_by_name['type']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['tombstone']._options = None
  _CONNECTORDEFINITION.fields_by_name['tombstone']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['public']._options = None
  _CONNECTORDEFINITION.fields_by_name['public']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['custom']._options = None
  _CONNECTORDEFINITION.fields_by_name['custom']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['vendor']._options = None
  _CONNECTORDEFINITION.fields_by_name['vendor']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['vendor_attributes']._options = None
  _CONNECTORDEFINITION.fields_by_name['vendor_attributes']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['source_url']._options = None
  _CONNECTORDEFINITION.fields_by_name['source_url']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['version']._options = None
  _CONNECTORDEFINITION.fields_by_name['version']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['tasks']._options = None
  _CONNECTORDEFINITION.fields_by_name['tasks']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['description']._options = None
  _CONNECTORDEFINITION.fields_by_name['description']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['release_stage']._options = None
  _CONNECTORDEFINITION.fields_by_name['release_stage']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION._options = None
  _CONNECTORDEFINITION._serialized_options = b'\352A_\n$api.instill.tech/ConnectorDefinition\022\032connector-definitions/{id}\022\033connector-definitions/{uid}'
  _OPERATORSPEC_DATASPECIFICATIONSENTRY._options = None
  _OPERATORSPEC_DATASPECIFICATIONSENTRY._serialized_options = b'8\001'
  _OPERATORSPEC.fields_by_name['component_specification']._options = None
  _OPERATORSPEC.fields_by_name['component_specification']._serialized_options = b'\342A\001\002'
  _OPERATORSPEC.fields_by_name['data_specifications']._options = None
  _OPERATORSPEC.fields_by_name['data_specifications']._serialized_options = b'\342A\001\002'
  _OPERATORDEFINITION.fields_by_name['name']._options = None
  _OPERATORDEFINITION.fields_by_name['name']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['uid']._options = None
  _OPERATORDEFINITION.fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['id']._options = None
  _OPERATORDEFINITION.fields_by_name['id']._serialized_options = b'\342A\001\005'
  _OPERATORDEFINITION.fields_by_name['title']._options = None
  _OPERATORDEFINITION.fields_by_name['title']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['documentation_url']._options = None
  _OPERATORDEFINITION.fields_by_name['documentation_url']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['icon']._options = None
  _OPERATORDEFINITION.fields_by_name['icon']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['spec']._options = None
  _OPERATORDEFINITION.fields_by_name['spec']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['tombstone']._options = None
  _OPERATORDEFINITION.fields_by_name['tombstone']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['public']._options = None
  _OPERATORDEFINITION.fields_by_name['public']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['custom']._options = None
  _OPERATORDEFINITION.fields_by_name['custom']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['source_url']._options = None
  _OPERATORDEFINITION.fields_by_name['source_url']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['version']._options = None
  _OPERATORDEFINITION.fields_by_name['version']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['tasks']._options = None
  _OPERATORDEFINITION.fields_by_name['tasks']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['description']._options = None
  _OPERATORDEFINITION.fields_by_name['description']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['release_stage']._options = None
  _OPERATORDEFINITION.fields_by_name['release_stage']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION._options = None
  _OPERATORDEFINITION._serialized_options = b'\352A\\\n#api.instill.tech/OperatorDefinition\022\031operator-definitions/{id}\022\032operator-definitions/{uid}'
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['view']._options = None
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['filter']._options = None
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['page']._options = None
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['page']._serialized_options = b'\342A\001\001'
  _LISTCONNECTORDEFINITIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCONNECTORDEFINITIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTCONNECTORDEFINITIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCONNECTORDEFINITIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTCONNECTORDEFINITIONSREQUEST.fields_by_name['filter']._options = None
  _LISTCONNECTORDEFINITIONSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTCONNECTORDEFINITIONSREQUEST.fields_by_name['view']._options = None
  _LISTCONNECTORDEFINITIONSREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _GETCONNECTORDEFINITIONREQUEST.fields_by_name['name']._options = None
  _GETCONNECTORDEFINITIONREQUEST.fields_by_name['name']._serialized_options = b'\222A\037\312>\034\372\002\031connector_definition_name\342A\001\002\372A&\n$api.instill.tech/ConnectorDefinition'
  _GETCONNECTORDEFINITIONREQUEST.fields_by_name['view']._options = None
  _GETCONNECTORDEFINITIONREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTOPERATORDEFINITIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTOPERATORDEFINITIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTOPERATORDEFINITIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTOPERATORDEFINITIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTOPERATORDEFINITIONSREQUEST.fields_by_name['filter']._options = None
  _LISTOPERATORDEFINITIONSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTOPERATORDEFINITIONSREQUEST.fields_by_name['view']._options = None
  _LISTOPERATORDEFINITIONSREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _GETOPERATORDEFINITIONREQUEST.fields_by_name['name']._options = None
  _GETOPERATORDEFINITIONREQUEST.fields_by_name['name']._serialized_options = b'\222A\036\312>\033\372\002\030operator_definition_name\342A\001\002\372A%\n#api.instill.tech/OperatorDefinition'
  _GETOPERATORDEFINITIONREQUEST.fields_by_name['view']._options = None
  _GETOPERATORDEFINITIONREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _globals['_CONNECTORTYPE']._serialized_start=6246
  _globals['_CONNECTORTYPE']._serialized_end=6448
  _globals['_COMPONENTDEFINITION']._serialized_start=244
  _globals['_COMPONENTDEFINITION']._serialized_end=1636
  _globals['_COMPONENTDEFINITION_SPEC']._serialized_start=1053
  _globals['_COMPONENTDEFINITION_SPEC']._serialized_end=1384
  _globals['_COMPONENTDEFINITION_SPEC_DATASPECIFICATIONSENTRY']._serialized_start=1275
  _globals['_COMPONENTDEFINITION_SPEC_DATASPECIFICATIONSENTRY']._serialized_end=1384
  _globals['_COMPONENTDEFINITION_VIEW']._serialized_start=1386
  _globals['_COMPONENTDEFINITION_VIEW']._serialized_end=1445
  _globals['_COMPONENTDEFINITION_RELEASESTAGE']._serialized_start=1448
  _globals['_COMPONENTDEFINITION_RELEASESTAGE']._serialized_end=1636
  _globals['_DATASPECIFICATION']._serialized_start=1638
  _globals['_DATASPECIFICATION']._serialized_end=1765
  _globals['_CONNECTORSPEC']._serialized_start=1768
  _globals['_CONNECTORSPEC']._serialized_end=2109
  _globals['_CONNECTORSPEC_DATASPECIFICATIONSENTRY']._serialized_start=1275
  _globals['_CONNECTORSPEC_DATASPECIFICATIONSENTRY']._serialized_end=1384
  _globals['_CONNECTORDEFINITION']._serialized_start=2112
  _globals['_CONNECTORDEFINITION']._serialized_end=3013
  _globals['_OPERATORSPEC']._serialized_start=3016
  _globals['_OPERATORSPEC']._serialized_end=3349
  _globals['_OPERATORSPEC_DATASPECIFICATIONSENTRY']._serialized_start=1275
  _globals['_OPERATORSPEC_DATASPECIFICATIONSENTRY']._serialized_end=1384
  _globals['_OPERATORDEFINITION']._serialized_start=3352
  _globals['_OPERATORDEFINITION']._serialized_end=4080
  _globals['_LISTCOMPONENTDEFINITIONSREQUEST']._serialized_start=4083
  _globals['_LISTCOMPONENTDEFINITIONSREQUEST']._serialized_end=4349
  _globals['_LISTCOMPONENTDEFINITIONSRESPONSE']._serialized_start=4352
  _globals['_LISTCOMPONENTDEFINITIONSRESPONSE']._serialized_end=4567
  _globals['_LISTCONNECTORDEFINITIONSREQUEST']._serialized_start=4570
  _globals['_LISTCONNECTORDEFINITIONSREQUEST']._serialized_end=4853
  _globals['_LISTCONNECTORDEFINITIONSRESPONSE']._serialized_start=4856
  _globals['_LISTCONNECTORDEFINITIONSRESPONSE']._serialized_end=5056
  _globals['_GETCONNECTORDEFINITIONREQUEST']._serialized_start=5059
  _globals['_GETCONNECTORDEFINITIONREQUEST']._serialized_end=5284
  _globals['_GETCONNECTORDEFINITIONRESPONSE']._serialized_start=5286
  _globals['_GETCONNECTORDEFINITIONRESPONSE']._serialized_end=5411
  _globals['_LISTOPERATORDEFINITIONSREQUEST']._serialized_start=5414
  _globals['_LISTOPERATORDEFINITIONSREQUEST']._serialized_end=5696
  _globals['_LISTOPERATORDEFINITIONSRESPONSE']._serialized_start=5699
  _globals['_LISTOPERATORDEFINITIONSRESPONSE']._serialized_end=5895
  _globals['_GETOPERATORDEFINITIONREQUEST']._serialized_start=5898
  _globals['_GETOPERATORDEFINITIONREQUEST']._serialized_end=6120
  _globals['_GETOPERATORDEFINITIONRESPONSE']._serialized_start=6122
  _globals['_GETOPERATORDEFINITIONRESPONSE']._serialized_end=6243
# @@protoc_insertion_point(module_scope)
