# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from model.model.v1alpha import model_definition_pb2 as model_dot_model_dot_v1alpha_dot_model__definition__pb2
from model.model.v1alpha import model_pb2 as model_dot_model_dot_v1alpha_dot_model__pb2


class ModelPublicServiceStub(object):
    """Model

    ModelPublicService exposes the public endpoints that allow clients to manage
    models.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Liveness = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/Liveness',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.LivenessRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.LivenessResponse.FromString,
                )
        self.Readiness = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/Readiness',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessResponse.FromString,
                )
        self.ListModelDefinitions = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListModelDefinitions',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsResponse.FromString,
                )
        self.ListAvailableRegions = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListAvailableRegions',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListAvailableRegionsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListAvailableRegionsResponse.FromString,
                )
        self.GetModelDefinition = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetModelDefinition',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionResponse.FromString,
                )
        self.ListModels = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListModels',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsResponse.FromString,
                )
        self.LookUpModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/LookUpModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelResponse.FromString,
                )
        self.ListNamespaceModels = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListNamespaceModels',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelsResponse.FromString,
                )
        self.CreateNamespaceModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/CreateNamespaceModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateNamespaceModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateNamespaceModelResponse.FromString,
                )
        self.GetNamespaceModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetNamespaceModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceModelResponse.FromString,
                )
        self.UpdateNamespaceModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/UpdateNamespaceModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateNamespaceModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateNamespaceModelResponse.FromString,
                )
        self.DeleteNamespaceModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/DeleteNamespaceModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelResponse.FromString,
                )
        self.RenameNamespaceModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/RenameNamespaceModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameNamespaceModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameNamespaceModelResponse.FromString,
                )
        self.WatchNamespaceModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/WatchNamespaceModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceModelResponse.FromString,
                )
        self.WatchNamespaceLatestModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/WatchNamespaceLatestModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceLatestModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceLatestModelResponse.FromString,
                )
        self.ListNamespaceModelVersions = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListNamespaceModelVersions',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelVersionsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelVersionsResponse.FromString,
                )
        self.DeleteNamespaceModelVersion = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/DeleteNamespaceModelVersion',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelVersionRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelVersionResponse.FromString,
                )
        self.TriggerNamespaceModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerNamespaceModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelResponse.FromString,
                )
        self.TriggerAsyncNamespaceModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerAsyncNamespaceModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceModelResponse.FromString,
                )
        self.TriggerNamespaceLatestModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerNamespaceLatestModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelResponse.FromString,
                )
        self.TriggerAsyncNamespaceLatestModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerAsyncNamespaceLatestModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceLatestModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceLatestModelResponse.FromString,
                )
        self.TriggerNamespaceModelBinaryFileUpload = channel.stream_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerNamespaceModelBinaryFileUpload',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelBinaryFileUploadRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelBinaryFileUploadResponse.FromString,
                )
        self.TriggerNamespaceLatestModelBinaryFileUpload = channel.stream_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerNamespaceLatestModelBinaryFileUpload',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelBinaryFileUploadRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelBinaryFileUploadResponse.FromString,
                )
        self.GetNamespaceLatestModelOperation = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetNamespaceLatestModelOperation',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceLatestModelOperationRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceLatestModelOperationResponse.FromString,
                )
        self.GetModelOperation = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetModelOperation',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationResponse.FromString,
                )
        self.ListUserModels = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListUserModels',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsResponse.FromString,
                )
        self.CreateUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/CreateUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelResponse.FromString,
                )
        self.GetUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelResponse.FromString,
                )
        self.UpdateUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/UpdateUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelResponse.FromString,
                )
        self.DeleteUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/DeleteUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelResponse.FromString,
                )
        self.RenameUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/RenameUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelResponse.FromString,
                )
        self.WatchUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/WatchUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelResponse.FromString,
                )
        self.WatchUserLatestModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/WatchUserLatestModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserLatestModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserLatestModelResponse.FromString,
                )
        self.ListUserModelVersions = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListUserModelVersions',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelVersionsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelVersionsResponse.FromString,
                )
        self.DeleteUserModelVersion = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/DeleteUserModelVersion',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelVersionRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelVersionResponse.FromString,
                )
        self.TriggerUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelResponse.FromString,
                )
        self.TriggerAsyncUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerAsyncUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserModelResponse.FromString,
                )
        self.TriggerUserLatestModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerUserLatestModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserLatestModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserLatestModelResponse.FromString,
                )
        self.TriggerAsyncUserLatestModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerAsyncUserLatestModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserLatestModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserLatestModelResponse.FromString,
                )
        self.TriggerUserModelBinaryFileUpload = channel.stream_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerUserModelBinaryFileUpload',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadResponse.FromString,
                )
        self.ListOrganizationModels = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListOrganizationModels',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsResponse.FromString,
                )
        self.CreateOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/CreateOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelResponse.FromString,
                )
        self.GetOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelResponse.FromString,
                )
        self.UpdateOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/UpdateOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelResponse.FromString,
                )
        self.DeleteOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/DeleteOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelResponse.FromString,
                )
        self.RenameOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/RenameOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelResponse.FromString,
                )
        self.WatchOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/WatchOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelResponse.FromString,
                )
        self.WatchOrganizationLatestModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/WatchOrganizationLatestModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationLatestModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationLatestModelResponse.FromString,
                )
        self.ListOrganizationModelVersions = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListOrganizationModelVersions',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelVersionsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelVersionsResponse.FromString,
                )
        self.DeleteOrganizationModelVersion = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/DeleteOrganizationModelVersion',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelVersionRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelVersionResponse.FromString,
                )
        self.TriggerOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelResponse.FromString,
                )
        self.TriggerAsyncOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerAsyncOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationModelResponse.FromString,
                )
        self.TriggerOrganizationLatestModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerOrganizationLatestModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationLatestModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationLatestModelResponse.FromString,
                )
        self.TriggerAsyncOrganizationLatestModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerAsyncOrganizationLatestModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationLatestModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationLatestModelResponse.FromString,
                )
        self.TriggerOrganizationModelBinaryFileUpload = channel.stream_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerOrganizationModelBinaryFileUpload',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadResponse.FromString,
                )
        self.GetUserLatestModelOperation = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetUserLatestModelOperation',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserLatestModelOperationRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserLatestModelOperationResponse.FromString,
                )
        self.GetOrganizationLatestModelOperation = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetOrganizationLatestModelOperation',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationLatestModelOperationRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationLatestModelOperationResponse.FromString,
                )


class ModelPublicServiceServicer(object):
    """Model

    ModelPublicService exposes the public endpoints that allow clients to manage
    models.
    """

    def Liveness(self, request, context):
        """Check if the model server is alive

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Readiness(self, request, context):
        """Check if the model server is ready

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListModelDefinitions(self, request, context):
        """List model definitions

        Returns a paginated list of model definitions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAvailableRegions(self, request, context):
        """List available regions

        Returns a paginated list of available regions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelDefinition(self, request, context):
        """Get a model definition

        Returns the details of a model definition.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListModels(self, request, context):
        """List models

        Returns a paginated list of models.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LookUpModel(self, request, context):
        """Get a model by UID

        Returns the details of a model by a permalink defined by the resource UID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNamespaceModels(self, request, context):
        """List namespace models

        Returns a paginated list of models.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNamespaceModel(self, request, context):
        """Create a new model

        Creates a new model under the parenthood of a namespace. This is an
        asynchronous endpoint, i.e., the server will not wait for the model to be
        created in order to respond. Instead, it will return a response with the
        necessary information to access the result and status of the creation
        operation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNamespaceModel(self, request, context):
        """Get a model

        Returns the detail of a model, accessing it by the model ID and its parent namespace.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNamespaceModel(self, request, context):
        """Update a model

        Updates a model, accessing it by its resource name, which is defined by
        the parent namespace and the ID of the model.

        In REST requests, only the supplied model fields will be taken into
        account when updating the resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNamespaceModel(self, request, context):
        """Delete a model

        Deletes a model, accesing it by its resource name, which is defined by the
        parent namespace and the ID of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RenameNamespaceModel(self, request, context):
        """Rename a model

        Renames a model, accesing it by its resource name, which is defined by the
        parent namespace and the ID of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchNamespaceModel(self, request, context):
        """Watch the state of a model version

        Returns the state of a model. The model resource allocation and scaling actions take some
        time, during which a model will be in various state. This endpoint
        allows clients to track the state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchNamespaceLatestModel(self, request, context):
        """Watch the state of the latest model version

        Returns the state of the latest model version. The model resource allocation and scaling actions
        take some time, during which a model will be in various state. This endpoint
        allows clients to track the state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNamespaceModelVersions(self, request, context):
        """List namespace model versions

        Returns a paginated list of version of a model namespace that belong to the specified namespace.
        Contains model version and digest.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNamespaceModelVersion(self, request, context):
        """Delete a model version

        Deletes a model version, accesing it by its resource name, which is defined by the
        parent namespace and the ID of the model, and version.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerNamespaceModel(self, request, context):
        """Trigger model inference

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerAsyncNamespaceModel(self, request, context):
        """Trigger model inference asynchronously

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerNamespaceLatestModel(self, request, context):
        """Trigger model inference

        Triggers the latest deployed model version to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerAsyncNamespaceLatestModel(self, request, context):
        """Trigger model inference asynchronously

        Triggers the latest deployed model version to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerNamespaceModelBinaryFileUpload(self, request_iterator, context):
        """Trigger model inference with a binary input

        Triggers a deployed model to infer the result of a task or question,
        submitted as a binary file.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerNamespaceLatestModelBinaryFileUpload(self, request_iterator, context):
        """Trigger model inference with a binary input

        Triggers the latest deployed model version to infer the result of a set of task or
        questions, submitted as a binary file.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNamespaceLatestModelOperation(self, request, context):
        """Get the details of the latest long-running operation from a namespace model

        This method allows requesters to request the status and outcome of
        long-running operations in a model, such as deployment.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelOperation(self, request, context):
        """Get the details of a long-running operation

        This method allows requesters to request the status and outcome of
        long-running operations in a model, such as deployment.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserModels(self, request, context):
        """The following endpoints are all deprecated

        List user models

        Returns a paginated list of models that belong to the specified user. The
        parent user may be different from the authenticated user, in which case
        the results will contain the models that are visible to the latter.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUserModel(self, request, context):
        """Create a new model

        Creates a new model under the parenthood of a user. This is an
        asynchronous endpoint, i.e., the server will not wait for the model to be
        created in order to respond. Instead, it will return a response with the
        necessary information to access the result and status of the creation
        operation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserModel(self, request, context):
        """Get a model

        Returns the detail of a model, accessing it by the model ID and its parent user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserModel(self, request, context):
        """Update a model

        Updates a model, accessing it by its resource name, which is defined by
        the parent user and the ID of the model.

        In REST requests, only the supplied model fields will be taken into
        account when updating the resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUserModel(self, request, context):
        """Delete a model

        Deletes a model, accesing it by its resource name, which is defined by the
        parent user and the ID of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RenameUserModel(self, request, context):
        """Rename a model

        Renames a model, accesing it by its resource name, which is defined by the
        parent user and the ID of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchUserModel(self, request, context):
        """Watch the state of a model version

        Returns the state of a model. The model resource allocation and scaling actions take some
        time, during which a model will be in various state. This endpoint
        allows clients to track the state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchUserLatestModel(self, request, context):
        """Watch the state of the latest model version

        Returns the state of the latest model version. The model resource allocation and scaling actions
        take some time, during which a model will be in various state. This endpoint
        allows clients to track the state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserModelVersions(self, request, context):
        """List user model versions

        Returns a paginated list of version of a model namespace that belong to the specified user.
        Contains model version and digest.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUserModelVersion(self, request, context):
        """Delete a model version

        Deletes a model version, accesing it by its resource name, which is defined by the
        parent user and the ID of the model, and version.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerUserModel(self, request, context):
        """/////////////////////////////////////////////////////

        Trigger model inference

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerAsyncUserModel(self, request, context):
        """Trigger model inference asynchronously

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerUserLatestModel(self, request, context):
        """Trigger model inference

        Triggers the latest deployed model version to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerAsyncUserLatestModel(self, request, context):
        """Trigger model inference asynchronously

        Triggers the latest deployed model version to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerUserModelBinaryFileUpload(self, request_iterator, context):
        """Trigger model inference with a binary input

        Triggers a deployed model to infer the result of a task or question,
        submitted as a binary file.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizationModels(self, request, context):
        """List organization models

        Returns a paginated list of models that belong to the specified organization. The
        parent organization may be different from the authenticated organization, in which case
        the results will contain the models that are visible to the latter.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrganizationModel(self, request, context):
        """Create a new model

        Creates a new model under the parenthood of an organization. This is an
        asynchronous endpoint, i.e., the server will not wait for the model to be
        created in order to respond. Instead, it will return a response with the
        necessary information to access the result and status of the creation
        operation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationModel(self, request, context):
        """Get a model

        Returns the detail of a model, accessing it by the model ID and its parent organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOrganizationModel(self, request, context):
        """Update a model

        Updates a model, accessing it by its resource name, which is defined by
        the parent organization and the ID of the model.

        In REST requests, only the supplied model fields will be taken into
        account when updating the resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganizationModel(self, request, context):
        """Delete a model

        Deletes a model, accesing it by its resource name, which is defined by the
        parent organization and the ID of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RenameOrganizationModel(self, request, context):
        """Rename a model

        Renames a model, accesing it by its resource name, which is defined by the
        parent organization and the ID of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchOrganizationModel(self, request, context):
        """Watch the state of a model version

        Returns the state of a model.  The model resource allocation and scaling actions
        take some time, during which a model will be in various state. This endpoint
        allows clients to track the state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchOrganizationLatestModel(self, request, context):
        """Watch the state of the latest model version

        Returns the state of the latest model version.  The model resource allocation and scaling actions
        take some time, during which a model will be in various state. This endpoint
        allows clients to track the state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizationModelVersions(self, request, context):
        """List organization model versions

        Returns a paginated list of version of a model namespace that belong to the specified organization.
        Contains model version and digest.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganizationModelVersion(self, request, context):
        """Delete a model version

        Deletes a model version, accesing it by its resource name, which is defined by the
        parent organization and the ID of the model, and version.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerOrganizationModel(self, request, context):
        """/////////////////////////////////////////////////////

        Trigger model inference

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerAsyncOrganizationModel(self, request, context):
        """Trigger model inference asynchronously

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerOrganizationLatestModel(self, request, context):
        """Trigger model inference

        Triggers the latest deployed model version to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerAsyncOrganizationLatestModel(self, request, context):
        """Trigger model inference asynchronously

        Triggers the latest deployed model version to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerOrganizationModelBinaryFileUpload(self, request_iterator, context):
        """Trigger model inference with a binary input

        Triggers a deployed model to infer the result of a task or question,
        submitted as a binary file.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserLatestModelOperation(self, request, context):
        """Get the details of the latest long-running operation from a user model

        This method allows requesters to request the status and outcome of
        long-running operations in a model, such as deployment.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationLatestModelOperation(self, request, context):
        """Get the details of the latest long-running operation from a organization model

        This method allows requesters to request the status and outcome of
        long-running operations in a model, such as deployment.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModelPublicServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Liveness': grpc.unary_unary_rpc_method_handler(
                    servicer.Liveness,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.LivenessRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.LivenessResponse.SerializeToString,
            ),
            'Readiness': grpc.unary_unary_rpc_method_handler(
                    servicer.Readiness,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessResponse.SerializeToString,
            ),
            'ListModelDefinitions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModelDefinitions,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsResponse.SerializeToString,
            ),
            'ListAvailableRegions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAvailableRegions,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListAvailableRegionsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListAvailableRegionsResponse.SerializeToString,
            ),
            'GetModelDefinition': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelDefinition,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionResponse.SerializeToString,
            ),
            'ListModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModels,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsResponse.SerializeToString,
            ),
            'LookUpModel': grpc.unary_unary_rpc_method_handler(
                    servicer.LookUpModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelResponse.SerializeToString,
            ),
            'ListNamespaceModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNamespaceModels,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelsResponse.SerializeToString,
            ),
            'CreateNamespaceModel': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNamespaceModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateNamespaceModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateNamespaceModelResponse.SerializeToString,
            ),
            'GetNamespaceModel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNamespaceModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceModelResponse.SerializeToString,
            ),
            'UpdateNamespaceModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNamespaceModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateNamespaceModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateNamespaceModelResponse.SerializeToString,
            ),
            'DeleteNamespaceModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNamespaceModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelResponse.SerializeToString,
            ),
            'RenameNamespaceModel': grpc.unary_unary_rpc_method_handler(
                    servicer.RenameNamespaceModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameNamespaceModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameNamespaceModelResponse.SerializeToString,
            ),
            'WatchNamespaceModel': grpc.unary_unary_rpc_method_handler(
                    servicer.WatchNamespaceModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceModelResponse.SerializeToString,
            ),
            'WatchNamespaceLatestModel': grpc.unary_unary_rpc_method_handler(
                    servicer.WatchNamespaceLatestModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceLatestModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceLatestModelResponse.SerializeToString,
            ),
            'ListNamespaceModelVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNamespaceModelVersions,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelVersionsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelVersionsResponse.SerializeToString,
            ),
            'DeleteNamespaceModelVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNamespaceModelVersion,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelVersionRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelVersionResponse.SerializeToString,
            ),
            'TriggerNamespaceModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerNamespaceModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelResponse.SerializeToString,
            ),
            'TriggerAsyncNamespaceModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerAsyncNamespaceModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceModelResponse.SerializeToString,
            ),
            'TriggerNamespaceLatestModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerNamespaceLatestModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelResponse.SerializeToString,
            ),
            'TriggerAsyncNamespaceLatestModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerAsyncNamespaceLatestModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceLatestModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceLatestModelResponse.SerializeToString,
            ),
            'TriggerNamespaceModelBinaryFileUpload': grpc.stream_unary_rpc_method_handler(
                    servicer.TriggerNamespaceModelBinaryFileUpload,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelBinaryFileUploadRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelBinaryFileUploadResponse.SerializeToString,
            ),
            'TriggerNamespaceLatestModelBinaryFileUpload': grpc.stream_unary_rpc_method_handler(
                    servicer.TriggerNamespaceLatestModelBinaryFileUpload,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelBinaryFileUploadRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelBinaryFileUploadResponse.SerializeToString,
            ),
            'GetNamespaceLatestModelOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNamespaceLatestModelOperation,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceLatestModelOperationRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceLatestModelOperationResponse.SerializeToString,
            ),
            'GetModelOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelOperation,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationResponse.SerializeToString,
            ),
            'ListUserModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserModels,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsResponse.SerializeToString,
            ),
            'CreateUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelResponse.SerializeToString,
            ),
            'GetUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelResponse.SerializeToString,
            ),
            'UpdateUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelResponse.SerializeToString,
            ),
            'DeleteUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelResponse.SerializeToString,
            ),
            'RenameUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.RenameUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelResponse.SerializeToString,
            ),
            'WatchUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.WatchUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelResponse.SerializeToString,
            ),
            'WatchUserLatestModel': grpc.unary_unary_rpc_method_handler(
                    servicer.WatchUserLatestModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserLatestModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserLatestModelResponse.SerializeToString,
            ),
            'ListUserModelVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserModelVersions,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelVersionsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelVersionsResponse.SerializeToString,
            ),
            'DeleteUserModelVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUserModelVersion,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelVersionRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelVersionResponse.SerializeToString,
            ),
            'TriggerUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelResponse.SerializeToString,
            ),
            'TriggerAsyncUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerAsyncUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserModelResponse.SerializeToString,
            ),
            'TriggerUserLatestModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerUserLatestModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserLatestModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserLatestModelResponse.SerializeToString,
            ),
            'TriggerAsyncUserLatestModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerAsyncUserLatestModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserLatestModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserLatestModelResponse.SerializeToString,
            ),
            'TriggerUserModelBinaryFileUpload': grpc.stream_unary_rpc_method_handler(
                    servicer.TriggerUserModelBinaryFileUpload,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadResponse.SerializeToString,
            ),
            'ListOrganizationModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizationModels,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsResponse.SerializeToString,
            ),
            'CreateOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelResponse.SerializeToString,
            ),
            'GetOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelResponse.SerializeToString,
            ),
            'UpdateOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelResponse.SerializeToString,
            ),
            'DeleteOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelResponse.SerializeToString,
            ),
            'RenameOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.RenameOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelResponse.SerializeToString,
            ),
            'WatchOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.WatchOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelResponse.SerializeToString,
            ),
            'WatchOrganizationLatestModel': grpc.unary_unary_rpc_method_handler(
                    servicer.WatchOrganizationLatestModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationLatestModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationLatestModelResponse.SerializeToString,
            ),
            'ListOrganizationModelVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizationModelVersions,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelVersionsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelVersionsResponse.SerializeToString,
            ),
            'DeleteOrganizationModelVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganizationModelVersion,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelVersionRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelVersionResponse.SerializeToString,
            ),
            'TriggerOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelResponse.SerializeToString,
            ),
            'TriggerAsyncOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerAsyncOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationModelResponse.SerializeToString,
            ),
            'TriggerOrganizationLatestModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerOrganizationLatestModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationLatestModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationLatestModelResponse.SerializeToString,
            ),
            'TriggerAsyncOrganizationLatestModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerAsyncOrganizationLatestModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationLatestModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationLatestModelResponse.SerializeToString,
            ),
            'TriggerOrganizationModelBinaryFileUpload': grpc.stream_unary_rpc_method_handler(
                    servicer.TriggerOrganizationModelBinaryFileUpload,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadResponse.SerializeToString,
            ),
            'GetUserLatestModelOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserLatestModelOperation,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserLatestModelOperationRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserLatestModelOperationResponse.SerializeToString,
            ),
            'GetOrganizationLatestModelOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationLatestModelOperation,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationLatestModelOperationRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationLatestModelOperationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'model.model.v1alpha.ModelPublicService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ModelPublicService(object):
    """Model

    ModelPublicService exposes the public endpoints that allow clients to manage
    models.
    """

    @staticmethod
    def Liveness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/Liveness',
            model_dot_model_dot_v1alpha_dot_model__pb2.LivenessRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.LivenessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Readiness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/Readiness',
            model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListModelDefinitions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListModelDefinitions',
            model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAvailableRegions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListAvailableRegions',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListAvailableRegionsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListAvailableRegionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelDefinition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetModelDefinition',
            model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListModels',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LookUpModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/LookUpModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNamespaceModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListNamespaceModels',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateNamespaceModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/CreateNamespaceModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateNamespaceModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateNamespaceModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNamespaceModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetNamespaceModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNamespaceModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/UpdateNamespaceModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.UpdateNamespaceModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UpdateNamespaceModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNamespaceModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/DeleteNamespaceModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RenameNamespaceModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/RenameNamespaceModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.RenameNamespaceModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.RenameNamespaceModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchNamespaceModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/WatchNamespaceModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchNamespaceLatestModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/WatchNamespaceLatestModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceLatestModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchNamespaceLatestModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNamespaceModelVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListNamespaceModelVersions',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelVersionsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListNamespaceModelVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNamespaceModelVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/DeleteNamespaceModelVersion',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelVersionRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteNamespaceModelVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerNamespaceModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerNamespaceModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerAsyncNamespaceModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerAsyncNamespaceModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerNamespaceLatestModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerNamespaceLatestModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerAsyncNamespaceLatestModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerAsyncNamespaceLatestModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceLatestModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncNamespaceLatestModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerNamespaceModelBinaryFileUpload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/model.model.v1alpha.ModelPublicService/TriggerNamespaceModelBinaryFileUpload',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelBinaryFileUploadRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceModelBinaryFileUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerNamespaceLatestModelBinaryFileUpload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/model.model.v1alpha.ModelPublicService/TriggerNamespaceLatestModelBinaryFileUpload',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelBinaryFileUploadRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerNamespaceLatestModelBinaryFileUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNamespaceLatestModelOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetNamespaceLatestModelOperation',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceLatestModelOperationRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetNamespaceLatestModelOperationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetModelOperation',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListUserModels',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/CreateUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/UpdateUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/DeleteUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RenameUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/RenameUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/WatchUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchUserLatestModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/WatchUserLatestModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserLatestModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserLatestModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserModelVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListUserModelVersions',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelVersionsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUserModelVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/DeleteUserModelVersion',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelVersionRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerAsyncUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerAsyncUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerUserLatestModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerUserLatestModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserLatestModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserLatestModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerAsyncUserLatestModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerAsyncUserLatestModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserLatestModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncUserLatestModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerUserModelBinaryFileUpload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/model.model.v1alpha.ModelPublicService/TriggerUserModelBinaryFileUpload',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizationModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListOrganizationModels',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/CreateOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/UpdateOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/DeleteOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RenameOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/RenameOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/WatchOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchOrganizationLatestModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/WatchOrganizationLatestModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationLatestModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationLatestModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizationModelVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListOrganizationModelVersions',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelVersionsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganizationModelVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/DeleteOrganizationModelVersion',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelVersionRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerAsyncOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerAsyncOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerOrganizationLatestModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerOrganizationLatestModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationLatestModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationLatestModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerAsyncOrganizationLatestModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerAsyncOrganizationLatestModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationLatestModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerAsyncOrganizationLatestModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerOrganizationModelBinaryFileUpload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/model.model.v1alpha.ModelPublicService/TriggerOrganizationModelBinaryFileUpload',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserLatestModelOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetUserLatestModelOperation',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetUserLatestModelOperationRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetUserLatestModelOperationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationLatestModelOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetOrganizationLatestModelOperation',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationLatestModelOperationRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationLatestModelOperationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
