# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from artifact.artifact.v1alpha import artifact_pb2 as artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2
from artifact.artifact.v1alpha import chunk_pb2 as artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2


class ArtifactPublicServiceStub(object):
    """ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Liveness = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/Liveness',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessResponse.FromString,
                )
        self.Readiness = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/Readiness',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessResponse.FromString,
                )
        self.CreateKnowledgeBase = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/CreateKnowledgeBase',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.CreateKnowledgeBaseRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.CreateKnowledgeBaseResponse.FromString,
                )
        self.ListKnowledgeBases = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/ListKnowledgeBases',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBasesRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBasesResponse.FromString,
                )
        self.UpdateKnowledgeBase = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/UpdateKnowledgeBase',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UpdateKnowledgeBaseRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UpdateKnowledgeBaseResponse.FromString,
                )
        self.DeleteKnowledgeBase = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/DeleteKnowledgeBase',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseResponse.FromString,
                )
        self.UploadKnowledgeBaseFile = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/UploadKnowledgeBaseFile',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UploadKnowledgeBaseFileRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UploadKnowledgeBaseFileResponse.FromString,
                )
        self.DeleteKnowledgeBaseFile = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/DeleteKnowledgeBaseFile',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseFileRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseFileResponse.FromString,
                )
        self.ProcessKnowledgeBaseFiles = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/ProcessKnowledgeBaseFiles',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ProcessKnowledgeBaseFilesRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ProcessKnowledgeBaseFilesResponse.FromString,
                )
        self.ListKnowledgeBaseFiles = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/ListKnowledgeBaseFiles',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBaseFilesRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBaseFilesResponse.FromString,
                )
        self.ListChunks = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/ListChunks',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.ListChunksRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.ListChunksResponse.FromString,
                )
        self.GetSourceFile = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/GetSourceFile',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.GetSourceFileRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.GetSourceFileResponse.FromString,
                )
        self.UpdateChunk = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/UpdateChunk',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.UpdateChunkRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.UpdateChunkResponse.FromString,
                )
        self.SimilarityChunksSearch = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/SimilarityChunksSearch',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.SimilarityChunksSearchRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.SimilarityChunksSearchResponse.FromString,
                )


class ArtifactPublicServiceServicer(object):
    """ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    def Liveness(self, request, context):
        """Check if the artifact server is alive

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Readiness(self, request, context):
        """Check if the artifact server is ready

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateKnowledgeBase(self, request, context):
        """Create a knowledge base
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListKnowledgeBases(self, request, context):
        """Get all knowledge bases info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateKnowledgeBase(self, request, context):
        """Update a knowledge base info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteKnowledgeBase(self, request, context):
        """Delete a knowledge base
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadKnowledgeBaseFile(self, request, context):
        """Create a file
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteKnowledgeBaseFile(self, request, context):
        """Delete a file
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProcessKnowledgeBaseFiles(self, request, context):
        """process file
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListKnowledgeBaseFiles(self, request, context):
        """list files
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListChunks(self, request, context):
        """List chunks
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSourceFile(self, request, context):
        """Get source file
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateChunk(self, request, context):
        """Update chunk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SimilarityChunksSearch(self, request, context):
        """Similarity chunks search
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ArtifactPublicServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Liveness': grpc.unary_unary_rpc_method_handler(
                    servicer.Liveness,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessResponse.SerializeToString,
            ),
            'Readiness': grpc.unary_unary_rpc_method_handler(
                    servicer.Readiness,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessResponse.SerializeToString,
            ),
            'CreateKnowledgeBase': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateKnowledgeBase,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.CreateKnowledgeBaseRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.CreateKnowledgeBaseResponse.SerializeToString,
            ),
            'ListKnowledgeBases': grpc.unary_unary_rpc_method_handler(
                    servicer.ListKnowledgeBases,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBasesRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBasesResponse.SerializeToString,
            ),
            'UpdateKnowledgeBase': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateKnowledgeBase,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UpdateKnowledgeBaseRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UpdateKnowledgeBaseResponse.SerializeToString,
            ),
            'DeleteKnowledgeBase': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteKnowledgeBase,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseResponse.SerializeToString,
            ),
            'UploadKnowledgeBaseFile': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadKnowledgeBaseFile,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UploadKnowledgeBaseFileRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UploadKnowledgeBaseFileResponse.SerializeToString,
            ),
            'DeleteKnowledgeBaseFile': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteKnowledgeBaseFile,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseFileRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseFileResponse.SerializeToString,
            ),
            'ProcessKnowledgeBaseFiles': grpc.unary_unary_rpc_method_handler(
                    servicer.ProcessKnowledgeBaseFiles,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ProcessKnowledgeBaseFilesRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ProcessKnowledgeBaseFilesResponse.SerializeToString,
            ),
            'ListKnowledgeBaseFiles': grpc.unary_unary_rpc_method_handler(
                    servicer.ListKnowledgeBaseFiles,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBaseFilesRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBaseFilesResponse.SerializeToString,
            ),
            'ListChunks': grpc.unary_unary_rpc_method_handler(
                    servicer.ListChunks,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.ListChunksRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.ListChunksResponse.SerializeToString,
            ),
            'GetSourceFile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSourceFile,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.GetSourceFileRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.GetSourceFileResponse.SerializeToString,
            ),
            'UpdateChunk': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateChunk,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.UpdateChunkRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.UpdateChunkResponse.SerializeToString,
            ),
            'SimilarityChunksSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.SimilarityChunksSearch,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.SimilarityChunksSearchRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.SimilarityChunksSearchResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'artifact.artifact.v1alpha.ArtifactPublicService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ArtifactPublicService(object):
    """ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    @staticmethod
    def Liveness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/Liveness',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Readiness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/Readiness',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateKnowledgeBase(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/CreateKnowledgeBase',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.CreateKnowledgeBaseRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.CreateKnowledgeBaseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListKnowledgeBases(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/ListKnowledgeBases',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBasesRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBasesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateKnowledgeBase(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/UpdateKnowledgeBase',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UpdateKnowledgeBaseRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UpdateKnowledgeBaseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteKnowledgeBase(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/DeleteKnowledgeBase',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadKnowledgeBaseFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/UploadKnowledgeBaseFile',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UploadKnowledgeBaseFileRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UploadKnowledgeBaseFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteKnowledgeBaseFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/DeleteKnowledgeBaseFile',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseFileRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ProcessKnowledgeBaseFiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/ProcessKnowledgeBaseFiles',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ProcessKnowledgeBaseFilesRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ProcessKnowledgeBaseFilesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListKnowledgeBaseFiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/ListKnowledgeBaseFiles',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBaseFilesRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBaseFilesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListChunks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/ListChunks',
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.ListChunksRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.ListChunksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSourceFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/GetSourceFile',
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.GetSourceFileRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.GetSourceFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateChunk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/UpdateChunk',
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.UpdateChunkRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.UpdateChunkResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SimilarityChunksSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/SimilarityChunksSearch',
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.SimilarityChunksSearchRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.SimilarityChunksSearchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
