"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file

This is the POC for metric-backend service that supports
1. receiving usage reports from pipeline-backend and model-backend clients
2. uploading usage to InfluxDB
3. uploading usage to Stripe
4. responding usage/price enquiries from clients
"""
import google.protobuf.descriptor

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor
