# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/mgmt/v1beta/mgmt_private_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from core.mgmt.v1beta import mgmt_pb2 as core_dot_mgmt_dot_v1beta_dot_mgmt__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+core/mgmt/v1beta/mgmt_private_service.proto\x12\x10\x63ore.mgmt.v1beta\x1a\x1b\x63ore/mgmt/v1beta/mgmt.proto2\xda\x0b\n\x12MgmtPrivateService\x12\x65\n\x0eListUsersAdmin\x12\'.core.mgmt.v1beta.ListUsersAdminRequest\x1a(.core.mgmt.v1beta.ListUsersAdminResponse\"\x00\x12_\n\x0cGetUserAdmin\x12%.core.mgmt.v1beta.GetUserAdminRequest\x1a&.core.mgmt.v1beta.GetUserAdminResponse\"\x00\x12h\n\x0fLookUpUserAdmin\x12(.core.mgmt.v1beta.LookUpUserAdminRequest\x1a).core.mgmt.v1beta.LookUpUserAdminResponse\"\x00\x12}\n\x16ListOrganizationsAdmin\x12/.core.mgmt.v1beta.ListOrganizationsAdminRequest\x1a\x30.core.mgmt.v1beta.ListOrganizationsAdminResponse\"\x00\x12w\n\x14GetOrganizationAdmin\x12-.core.mgmt.v1beta.GetOrganizationAdminRequest\x1a..core.mgmt.v1beta.GetOrganizationAdminResponse\"\x00\x12\x80\x01\n\x17LookUpOrganizationAdmin\x12\x30.core.mgmt.v1beta.LookUpOrganizationAdminRequest\x1a\x31.core.mgmt.v1beta.LookUpOrganizationAdminResponse\"\x00\x12\x83\x01\n\x18GetUserSubscriptionAdmin\x12\x31.core.mgmt.v1beta.GetUserSubscriptionAdminRequest\x1a\x32.core.mgmt.v1beta.GetUserSubscriptionAdminResponse\"\x00\x12\x9b\x01\n GetOrganizationSubscriptionAdmin\x12\x39.core.mgmt.v1beta.GetOrganizationSubscriptionAdminRequest\x1a:.core.mgmt.v1beta.GetOrganizationSubscriptionAdminResponse\"\x00\x12t\n\x13SubtractCreditAdmin\x12,.core.mgmt.v1beta.SubtractCreditAdminRequest\x1a-.core.mgmt.v1beta.SubtractCreditAdminResponse\"\x00\x12\x80\x01\n\x17GetRemainingCreditAdmin\x12\x30.core.mgmt.v1beta.GetRemainingCreditAdminRequest\x1a\x31.core.mgmt.v1beta.GetRemainingCreditAdminResponse\"\x00\x12t\n\x13\x43heckNamespaceAdmin\x12,.core.mgmt.v1beta.CheckNamespaceAdminRequest\x1a-.core.mgmt.v1beta.CheckNamespaceAdminResponse\"\x00\x12\x83\x01\n\x18\x43heckNamespaceByUIDAdmin\x12\x31.core.mgmt.v1beta.CheckNamespaceByUIDAdminRequest\x1a\x32.core.mgmt.v1beta.CheckNamespaceByUIDAdminResponse\"\x00\x42\xd0\x01\n\x14\x63om.core.mgmt.v1betaB\x17MgmtPrivateServiceProtoP\x01Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\xa2\x02\x03\x43MX\xaa\x02\x10\x43ore.Mgmt.V1beta\xca\x02\x10\x43ore\\Mgmt\\V1beta\xe2\x02\x1c\x43ore\\Mgmt\\V1beta\\GPBMetadata\xea\x02\x12\x43ore::Mgmt::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core.mgmt.v1beta.mgmt_private_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.core.mgmt.v1betaB\027MgmtPrivateServiceProtoP\001Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\242\002\003CMX\252\002\020Core.Mgmt.V1beta\312\002\020Core\\Mgmt\\V1beta\342\002\034Core\\Mgmt\\V1beta\\GPBMetadata\352\002\022Core::Mgmt::V1beta'
  _globals['_MGMTPRIVATESERVICE']._serialized_start=95
  _globals['_MGMTPRIVATESERVICE']._serialized_end=1593
# @@protoc_insertion_point(module_scope)
