# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/model/v1alpha/task_keypoint.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from model.model.v1alpha import common_pb2 as model_dot_model_dot_v1alpha_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'model/model/v1alpha/task_keypoint.proto\x12\x13model.model.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\x1a model/model/v1alpha/common.proto\"F\n\x08Keypoint\x12\x12\n\x01x\x18\x01 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x01x\x12\x12\n\x01y\x18\x02 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x01y\x12\x12\n\x01v\x18\x03 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x01v\"\xba\x01\n\x0eKeypointObject\x12\x41\n\tkeypoints\x18\x01 \x03(\x0b\x32\x1d.model.model.v1alpha.KeypointB\x04\xe2\x41\x01\x03R\tkeypoints\x12\x1a\n\x05score\x18\x02 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x05score\x12I\n\x0c\x62ounding_box\x18\x03 \x01(\x0b\x32 .model.model.v1alpha.BoundingBoxB\x04\xe2\x41\x01\x03R\x0b\x62oundingBox\"[\n\rKeypointInput\x12\x1d\n\timage_url\x18\x01 \x01(\tH\x00R\x08imageUrl\x12#\n\x0cimage_base64\x18\x02 \x01(\tH\x00R\x0bimageBase64B\x06\n\x04type\"^\n\x13KeypointInputStream\x12\'\n\x0c\x66ile_lengths\x18\x01 \x03(\rB\x04\xe2\x41\x01\x02R\x0b\x66ileLengths\x12\x1e\n\x07\x63ontent\x18\x02 \x01(\x0c\x42\x04\xe2\x41\x01\x02R\x07\x63ontent\"U\n\x0eKeypointOutput\x12\x43\n\x07objects\x18\x01 \x03(\x0b\x32#.model.model.v1alpha.KeypointObjectB\x04\xe2\x41\x01\x03R\x07objectsB\xde\x01\n\x17\x63om.model.model.v1alphaB\x11TaskKeypointProtoP\x01ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\xa2\x02\x03MMX\xaa\x02\x13Model.Model.V1alpha\xca\x02\x13Model\\Model\\V1alpha\xe2\x02\x1fModel\\Model\\V1alpha\\GPBMetadata\xea\x02\x15Model::Model::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.model.v1alpha.task_keypoint_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.model.model.v1alphaB\021TaskKeypointProtoP\001ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\242\002\003MMX\252\002\023Model.Model.V1alpha\312\002\023Model\\Model\\V1alpha\342\002\037Model\\Model\\V1alpha\\GPBMetadata\352\002\025Model::Model::V1alpha'
  _KEYPOINT.fields_by_name['x']._options = None
  _KEYPOINT.fields_by_name['x']._serialized_options = b'\342A\001\003'
  _KEYPOINT.fields_by_name['y']._options = None
  _KEYPOINT.fields_by_name['y']._serialized_options = b'\342A\001\003'
  _KEYPOINT.fields_by_name['v']._options = None
  _KEYPOINT.fields_by_name['v']._serialized_options = b'\342A\001\003'
  _KEYPOINTOBJECT.fields_by_name['keypoints']._options = None
  _KEYPOINTOBJECT.fields_by_name['keypoints']._serialized_options = b'\342A\001\003'
  _KEYPOINTOBJECT.fields_by_name['score']._options = None
  _KEYPOINTOBJECT.fields_by_name['score']._serialized_options = b'\342A\001\003'
  _KEYPOINTOBJECT.fields_by_name['bounding_box']._options = None
  _KEYPOINTOBJECT.fields_by_name['bounding_box']._serialized_options = b'\342A\001\003'
  _KEYPOINTINPUTSTREAM.fields_by_name['file_lengths']._options = None
  _KEYPOINTINPUTSTREAM.fields_by_name['file_lengths']._serialized_options = b'\342A\001\002'
  _KEYPOINTINPUTSTREAM.fields_by_name['content']._options = None
  _KEYPOINTINPUTSTREAM.fields_by_name['content']._serialized_options = b'\342A\001\002'
  _KEYPOINTOUTPUT.fields_by_name['objects']._options = None
  _KEYPOINTOUTPUT.fields_by_name['objects']._serialized_options = b'\342A\001\003'
  _globals['_KEYPOINT']._serialized_start=131
  _globals['_KEYPOINT']._serialized_end=201
  _globals['_KEYPOINTOBJECT']._serialized_start=204
  _globals['_KEYPOINTOBJECT']._serialized_end=390
  _globals['_KEYPOINTINPUT']._serialized_start=392
  _globals['_KEYPOINTINPUT']._serialized_end=483
  _globals['_KEYPOINTINPUTSTREAM']._serialized_start=485
  _globals['_KEYPOINTINPUTSTREAM']._serialized_end=579
  _globals['_KEYPOINTOUTPUT']._serialized_start=581
  _globals['_KEYPOINTOUTPUT']._serialized_end=666
# @@protoc_insertion_point(module_scope)
