# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: artifact/artifact/v1alpha/artifact_private_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from artifact.artifact.v1alpha import artifact_pb2 as artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8artifact/artifact/v1alpha/artifact_private_service.proto\x12\x19\x61rtifact.artifact.v1alpha\x1a(artifact/artifact/v1alpha/artifact.proto2\xa7\x04\n\x16\x41rtifactPrivateService\x12\x81\x01\n\x12ListRepositoryTags\x12\x34.artifact.artifact.v1alpha.ListRepositoryTagsRequest\x1a\x35.artifact.artifact.v1alpha.ListRepositoryTagsResponse\x12{\n\x10GetRepositoryTag\x12\x32.artifact.artifact.v1alpha.GetRepositoryTagRequest\x1a\x33.artifact.artifact.v1alpha.GetRepositoryTagResponse\x12\x84\x01\n\x13\x43reateRepositoryTag\x12\x35.artifact.artifact.v1alpha.CreateRepositoryTagRequest\x1a\x36.artifact.artifact.v1alpha.CreateRepositoryTagResponse\x12\x84\x01\n\x13\x44\x65leteRepositoryTag\x12\x35.artifact.artifact.v1alpha.DeleteRepositoryTagRequest\x1a\x36.artifact.artifact.v1alpha.DeleteRepositoryTagResponseB\x8f\x02\n\x1d\x63om.artifact.artifact.v1alphaB\x1b\x41rtifactPrivateServiceProtoP\x01ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x19\x41rtifact.Artifact.V1alpha\xca\x02\x19\x41rtifact\\Artifact\\V1alpha\xe2\x02%Artifact\\Artifact\\V1alpha\\GPBMetadata\xea\x02\x1b\x41rtifact::Artifact::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'artifact.artifact.v1alpha.artifact_private_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.artifact.artifact.v1alphaB\033ArtifactPrivateServiceProtoP\001ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\242\002\003AAX\252\002\031Artifact.Artifact.V1alpha\312\002\031Artifact\\Artifact\\V1alpha\342\002%Artifact\\Artifact\\V1alpha\\GPBMetadata\352\002\033Artifact::Artifact::V1alpha'
  _globals['_ARTIFACTPRIVATESERVICE']._serialized_start=130
  _globals['_ARTIFACTPRIVATESERVICE']._serialized_end=681
# @@protoc_insertion_point(module_scope)
