# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/model/v1alpha/task_unspecified.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*model/model/v1alpha/task_unspecified.proto\x12\x13model.model.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1cgoogle/protobuf/struct.proto\"J\n\x10UnspecifiedInput\x12\x36\n\nraw_inputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructR\trawInputs\"S\n\x11UnspecifiedOutput\x12>\n\x0braw_outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x03R\nrawOutputsB\xe1\x01\n\x17\x63om.model.model.v1alphaB\x14TaskUnspecifiedProtoP\x01ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\xa2\x02\x03MMX\xaa\x02\x13Model.Model.V1alpha\xca\x02\x13Model\\Model\\V1alpha\xe2\x02\x1fModel\\Model\\V1alpha\\GPBMetadata\xea\x02\x15Model::Model::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.model.v1alpha.task_unspecified_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.model.model.v1alphaB\024TaskUnspecifiedProtoP\001ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\242\002\003MMX\252\002\023Model.Model.V1alpha\312\002\023Model\\Model\\V1alpha\342\002\037Model\\Model\\V1alpha\\GPBMetadata\352\002\025Model::Model::V1alpha'
  _UNSPECIFIEDOUTPUT.fields_by_name['raw_outputs']._options = None
  _UNSPECIFIEDOUTPUT.fields_by_name['raw_outputs']._serialized_options = b'\342A\001\003'
  _globals['_UNSPECIFIEDINPUT']._serialized_start=130
  _globals['_UNSPECIFIEDINPUT']._serialized_end=204
  _globals['_UNSPECIFIEDOUTPUT']._serialized_start=206
  _globals['_UNSPECIFIEDOUTPUT']._serialized_end=289
# @@protoc_insertion_point(module_scope)
