# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/model/v1alpha/task_instance_segmentation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from model.model.v1alpha import common_pb2 as model_dot_model_dot_v1alpha_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4model/model/v1alpha/task_instance_segmentation.proto\x12\x13model.model.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\x1a model/model/v1alpha/common.proto\"\xbd\x01\n\x1aInstanceSegmentationObject\x12\x16\n\x03rle\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x03rle\x12 \n\x08\x63\x61tegory\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\x08\x63\x61tegory\x12\x1a\n\x05score\x18\x03 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x05score\x12I\n\x0c\x62ounding_box\x18\x04 \x01(\x0b\x32 .model.model.v1alpha.BoundingBoxB\x04\xe2\x41\x01\x03R\x0b\x62oundingBox\"g\n\x19InstanceSegmentationInput\x12\x1d\n\timage_url\x18\x01 \x01(\tH\x00R\x08imageUrl\x12#\n\x0cimage_base64\x18\x02 \x01(\tH\x00R\x0bimageBase64B\x06\n\x04type\"j\n\x1fInstanceSegmentationInputStream\x12\'\n\x0c\x66ile_lengths\x18\x01 \x03(\rB\x04\xe2\x41\x01\x02R\x0b\x66ileLengths\x12\x1e\n\x07\x63ontent\x18\x02 \x01(\x0c\x42\x04\xe2\x41\x01\x02R\x07\x63ontent\"m\n\x1aInstanceSegmentationOutput\x12O\n\x07objects\x18\x01 \x03(\x0b\x32/.model.model.v1alpha.InstanceSegmentationObjectB\x04\xe2\x41\x01\x03R\x07objectsB\xea\x01\n\x17\x63om.model.model.v1alphaB\x1dTaskInstanceSegmentationProtoP\x01ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\xa2\x02\x03MMX\xaa\x02\x13Model.Model.V1alpha\xca\x02\x13Model\\Model\\V1alpha\xe2\x02\x1fModel\\Model\\V1alpha\\GPBMetadata\xea\x02\x15Model::Model::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.model.v1alpha.task_instance_segmentation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.model.model.v1alphaB\035TaskInstanceSegmentationProtoP\001ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\242\002\003MMX\252\002\023Model.Model.V1alpha\312\002\023Model\\Model\\V1alpha\342\002\037Model\\Model\\V1alpha\\GPBMetadata\352\002\025Model::Model::V1alpha'
  _INSTANCESEGMENTATIONOBJECT.fields_by_name['rle']._options = None
  _INSTANCESEGMENTATIONOBJECT.fields_by_name['rle']._serialized_options = b'\342A\001\003'
  _INSTANCESEGMENTATIONOBJECT.fields_by_name['category']._options = None
  _INSTANCESEGMENTATIONOBJECT.fields_by_name['category']._serialized_options = b'\342A\001\003'
  _INSTANCESEGMENTATIONOBJECT.fields_by_name['score']._options = None
  _INSTANCESEGMENTATIONOBJECT.fields_by_name['score']._serialized_options = b'\342A\001\003'
  _INSTANCESEGMENTATIONOBJECT.fields_by_name['bounding_box']._options = None
  _INSTANCESEGMENTATIONOBJECT.fields_by_name['bounding_box']._serialized_options = b'\342A\001\003'
  _INSTANCESEGMENTATIONINPUTSTREAM.fields_by_name['file_lengths']._options = None
  _INSTANCESEGMENTATIONINPUTSTREAM.fields_by_name['file_lengths']._serialized_options = b'\342A\001\002'
  _INSTANCESEGMENTATIONINPUTSTREAM.fields_by_name['content']._options = None
  _INSTANCESEGMENTATIONINPUTSTREAM.fields_by_name['content']._serialized_options = b'\342A\001\002'
  _INSTANCESEGMENTATIONOUTPUT.fields_by_name['objects']._options = None
  _INSTANCESEGMENTATIONOUTPUT.fields_by_name['objects']._serialized_options = b'\342A\001\003'
  _globals['_INSTANCESEGMENTATIONOBJECT']._serialized_start=145
  _globals['_INSTANCESEGMENTATIONOBJECT']._serialized_end=334
  _globals['_INSTANCESEGMENTATIONINPUT']._serialized_start=336
  _globals['_INSTANCESEGMENTATIONINPUT']._serialized_end=439
  _globals['_INSTANCESEGMENTATIONINPUTSTREAM']._serialized_start=441
  _globals['_INSTANCESEGMENTATIONINPUTSTREAM']._serialized_end=547
  _globals['_INSTANCESEGMENTATIONOUTPUT']._serialized_start=549
  _globals['_INSTANCESEGMENTATIONOUTPUT']._serialized_end=658
# @@protoc_insertion_point(module_scope)
