"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.struct_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class UnspecifiedInput(google.protobuf.message.Message):
    """UnspecifiedInput represents the input of an unspecified task."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAW_INPUTS_FIELD_NUMBER: builtins.int
    @property
    def raw_inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """A list of values for the task."""
    def __init__(
        self,
        *,
        raw_inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["raw_inputs", b"raw_inputs"]) -> None: ...

global___UnspecifiedInput = UnspecifiedInput

@typing_extensions.final
class UnspecifiedOutput(google.protobuf.message.Message):
    """UnspecifiedOutput contains the result of an unspecified task."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAW_OUTPUTS_FIELD_NUMBER: builtins.int
    @property
    def raw_outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """The task outputs."""
    def __init__(
        self,
        *,
        raw_outputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["raw_outputs", b"raw_outputs"]) -> None: ...

global___UnspecifiedOutput = UnspecifiedOutput
