# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/metric/v1beta/metric_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from core.metric.v1beta import metric_pb2 as core_dot_metric_dot_v1beta_dot_metric__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'core/metric/v1beta/metric_service.proto\x12\x12\x63ore.metric.v1beta\x1a\x1f\x63ore/metric/v1beta/metric.proto\x1a\x1bgoogle/api/visibility.proto2\xc3\x0c\n\x0fPipelineService\x12\x61\n\x0cGetPipelines\x12\'.core.metric.v1beta.GetPipelinesRequest\x1a(.core.metric.v1beta.GetPipelinesResponse\x12|\n\x15ReportPipelineTrigger\x12\x30.core.metric.v1beta.ReportPipelineTriggerRequest\x1a\x31.core.metric.v1beta.ReportPipelineTriggerResponse\x12\x7f\n\x16ReportPipelineTriggers\x12\x31.core.metric.v1beta.ReportPipelineTriggersRequest\x1a\x32.core.metric.v1beta.ReportPipelineTriggersResponse\x12\x88\x01\n\x19GetPipelineTriggerRecords\x12\x34.core.metric.v1beta.GetPipelineTriggerRecordsRequest\x1a\x35.core.metric.v1beta.GetPipelineTriggerRecordsResponse\x12\x94\x01\n\x1dGetBulkPipelineTriggerRecords\x12\x38.core.metric.v1beta.GetBulkPipelineTriggerRecordsRequest\x1a\x39.core.metric.v1beta.GetBulkPipelineTriggerRecordsResponse\x12\xa6\x01\n#GetCumulativePipelineTriggerRecords\x12>.core.metric.v1beta.GetCumulativePipelineTriggerRecordsRequest\x1a?.core.metric.v1beta.GetCumulativePipelineTriggerRecordsResponse\x12\xb2\x01\n\'GetBulkCumulativePipelineTriggerRecords\x12\x42.core.metric.v1beta.GetBulkCumulativePipelineTriggerRecordsRequest\x1a\x43.core.metric.v1beta.GetBulkCumulativePipelineTriggerRecordsResponse\x12\x88\x01\n\x19GetPipelineTriggerSummary\x12\x34.core.metric.v1beta.GetPipelineTriggerSummaryRequest\x1a\x35.core.metric.v1beta.GetPipelineTriggerSummaryResponse\x12\x9a\x01\n\x1fGetBulkPipelineTriggerSummaries\x12:.core.metric.v1beta.GetBulkPipelineTriggerSummariesRequest\x1a;.core.metric.v1beta.GetBulkPipelineTriggerSummariesResponse\x12\x82\x01\n\x17GetPipelineTriggerPrice\x12\x32.core.metric.v1beta.GetPipelineTriggerPriceRequest\x1a\x33.core.metric.v1beta.GetPipelineTriggerPriceResponse\x12\x8e\x01\n\x1bGetBulkPipelineTriggerPrice\x12\x36.core.metric.v1beta.GetBulkPipelineTriggerPriceRequest\x1a\x37.core.metric.v1beta.GetBulkPipelineTriggerPriceResponse\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL2\xb6\x0b\n\x0cModelService\x12X\n\tGetModels\x12$.core.metric.v1beta.GetModelsRequest\x1a%.core.metric.v1beta.GetModelsResponse\x12p\n\x11ReportModelOnline\x12,.core.metric.v1beta.ReportModelOnlineRequest\x1a-.core.metric.v1beta.ReportModelOnlineResponse\x12s\n\x12ReportModelOnlines\x12-.core.metric.v1beta.ReportModelOnlinesRequest\x1a..core.metric.v1beta.ReportModelOnlinesResponse\x12|\n\x15GetModelOnlineRecords\x12\x30.core.metric.v1beta.GetModelOnlineRecordsRequest\x1a\x31.core.metric.v1beta.GetModelOnlineRecordsResponse\x12\x88\x01\n\x19GetBulkModelOnlineRecords\x12\x34.core.metric.v1beta.GetBulkModelOnlineRecordsRequest\x1a\x35.core.metric.v1beta.GetBulkModelOnlineRecordsResponse\x12\x9a\x01\n\x1fGetCumulativeModelOnlineRecords\x12:.core.metric.v1beta.GetCumulativeModelOnlineRecordsRequest\x1a;.core.metric.v1beta.GetCumulativeModelOnlineRecordsResponse\x12\xa6\x01\n#GetBulkCumulativeModelOnlineRecords\x12>.core.metric.v1beta.GetBulkCumulativeModelOnlineRecordsRequest\x1a?.core.metric.v1beta.GetBulkCumulativeModelOnlineRecordsResponse\x12|\n\x15GetModelOnlineSummary\x12\x30.core.metric.v1beta.GetModelOnlineSummaryRequest\x1a\x31.core.metric.v1beta.GetModelOnlineSummaryResponse\x12\x88\x01\n\x19GetBulkModelOnlineSummary\x12\x34.core.metric.v1beta.GetBulkModelOnlineSummaryRequest\x1a\x35.core.metric.v1beta.GetBulkModelOnlineSummaryResponse\x12v\n\x13GetModelOnlinePrice\x12..core.metric.v1beta.GetModelOnlinePriceRequest\x1a/.core.metric.v1beta.GetModelOnlinePriceResponse\x12\x82\x01\n\x17GetBulkModelOnlinePrice\x12\x32.core.metric.v1beta.GetBulkModelOnlinePriceRequest\x1a\x33.core.metric.v1beta.GetBulkModelOnlinePriceResponse\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNALB\xd9\x01\n\x16\x63om.core.metric.v1betaB\x12MetricServiceProtoP\x01ZAgithub.com/instill-ai/protogen-go/core/metric/v1beta;metricv1beta\xa2\x02\x03\x43MX\xaa\x02\x12\x43ore.Metric.V1beta\xca\x02\x12\x43ore\\Metric\\V1beta\xe2\x02\x1e\x43ore\\Metric\\V1beta\\GPBMetadata\xea\x02\x14\x43ore::Metric::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core.metric.v1beta.metric_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.core.metric.v1betaB\022MetricServiceProtoP\001ZAgithub.com/instill-ai/protogen-go/core/metric/v1beta;metricv1beta\242\002\003CMX\252\002\022Core.Metric.V1beta\312\002\022Core\\Metric\\V1beta\342\002\036Core\\Metric\\V1beta\\GPBMetadata\352\002\024Core::Metric::V1beta'
  _PIPELINESERVICE._options = None
  _PIPELINESERVICE._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _MODELSERVICE._options = None
  _MODELSERVICE._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _globals['_PIPELINESERVICE']._serialized_start=126
  _globals['_PIPELINESERVICE']._serialized_end=1729
  _globals['_MODELSERVICE']._serialized_start=1732
  _globals['_MODELSERVICE']._serialized_end=3194
# @@protoc_insertion_point(module_scope)
