"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import collections.abc
import core.usage.v1beta.usage_pb2
import grpc
import grpc.aio
import typing

_T = typing.TypeVar('_T')

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta):
    ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore
    ...

class UsageServiceStub:
    """UsageService responds to incoming usage requests."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Liveness: grpc.UnaryUnaryMultiCallable[
        core.usage.v1beta.usage_pb2.LivenessRequest,
        core.usage.v1beta.usage_pb2.LivenessResponse,
    ]
    """Liveness method receives a LivenessRequest message and returns a
    LivenessResponse message.
    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    Readiness: grpc.UnaryUnaryMultiCallable[
        core.usage.v1beta.usage_pb2.ReadinessRequest,
        core.usage.v1beta.usage_pb2.ReadinessResponse,
    ]
    """Readiness method receives a ReadinessRequest message and returns a
    ReadinessResponse message.
    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    CreateSession: grpc.UnaryUnaryMultiCallable[
        core.usage.v1beta.usage_pb2.CreateSessionRequest,
        core.usage.v1beta.usage_pb2.CreateSessionResponse,
    ]
    """CreateSession method receives a CreateSessionRequest message and returns
    a CreateSessionResponse message.
    """
    SendSessionReport: grpc.UnaryUnaryMultiCallable[
        core.usage.v1beta.usage_pb2.SendSessionReportRequest,
        core.usage.v1beta.usage_pb2.SendSessionReportResponse,
    ]
    """SendSessionReport method receives a SendSessionReportRequest message and
    returns a SendSessionReportResponse message.
    """

class UsageServiceAsyncStub:
    """UsageService responds to incoming usage requests."""

    Liveness: grpc.aio.UnaryUnaryMultiCallable[
        core.usage.v1beta.usage_pb2.LivenessRequest,
        core.usage.v1beta.usage_pb2.LivenessResponse,
    ]
    """Liveness method receives a LivenessRequest message and returns a
    LivenessResponse message.
    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    Readiness: grpc.aio.UnaryUnaryMultiCallable[
        core.usage.v1beta.usage_pb2.ReadinessRequest,
        core.usage.v1beta.usage_pb2.ReadinessResponse,
    ]
    """Readiness method receives a ReadinessRequest message and returns a
    ReadinessResponse message.
    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    CreateSession: grpc.aio.UnaryUnaryMultiCallable[
        core.usage.v1beta.usage_pb2.CreateSessionRequest,
        core.usage.v1beta.usage_pb2.CreateSessionResponse,
    ]
    """CreateSession method receives a CreateSessionRequest message and returns
    a CreateSessionResponse message.
    """
    SendSessionReport: grpc.aio.UnaryUnaryMultiCallable[
        core.usage.v1beta.usage_pb2.SendSessionReportRequest,
        core.usage.v1beta.usage_pb2.SendSessionReportResponse,
    ]
    """SendSessionReport method receives a SendSessionReportRequest message and
    returns a SendSessionReportResponse message.
    """

class UsageServiceServicer(metaclass=abc.ABCMeta):
    """UsageService responds to incoming usage requests."""

    @abc.abstractmethod
    def Liveness(
        self,
        request: core.usage.v1beta.usage_pb2.LivenessRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.usage.v1beta.usage_pb2.LivenessResponse, collections.abc.Awaitable[core.usage.v1beta.usage_pb2.LivenessResponse]]:
        """Liveness method receives a LivenessRequest message and returns a
        LivenessResponse message.
        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
    @abc.abstractmethod
    def Readiness(
        self,
        request: core.usage.v1beta.usage_pb2.ReadinessRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.usage.v1beta.usage_pb2.ReadinessResponse, collections.abc.Awaitable[core.usage.v1beta.usage_pb2.ReadinessResponse]]:
        """Readiness method receives a ReadinessRequest message and returns a
        ReadinessResponse message.
        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
    @abc.abstractmethod
    def CreateSession(
        self,
        request: core.usage.v1beta.usage_pb2.CreateSessionRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.usage.v1beta.usage_pb2.CreateSessionResponse, collections.abc.Awaitable[core.usage.v1beta.usage_pb2.CreateSessionResponse]]:
        """CreateSession method receives a CreateSessionRequest message and returns
        a CreateSessionResponse message.
        """
    @abc.abstractmethod
    def SendSessionReport(
        self,
        request: core.usage.v1beta.usage_pb2.SendSessionReportRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.usage.v1beta.usage_pb2.SendSessionReportResponse, collections.abc.Awaitable[core.usage.v1beta.usage_pb2.SendSessionReportResponse]]:
        """SendSessionReport method receives a SendSessionReportRequest message and
        returns a SendSessionReportResponse message.
        """

def add_UsageServiceServicer_to_server(servicer: UsageServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
