# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vdp/pipeline/v1beta/pipeline_private_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from vdp.pipeline.v1beta import pipeline_pb2 as vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2vdp/pipeline/v1beta/pipeline_private_service.proto\x12\x13vdp.pipeline.v1beta\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a\"vdp/pipeline/v1beta/pipeline.proto2\xd7\x03\n\x16PipelinePrivateService\x12w\n\x12ListPipelinesAdmin\x12..vdp.pipeline.v1beta.ListPipelinesAdminRequest\x1a/.vdp.pipeline.v1beta.ListPipelinesAdminResponse\"\x00\x12z\n\x13LookUpPipelineAdmin\x12/.vdp.pipeline.v1beta.LookUpPipelineAdminRequest\x1a\x30.vdp.pipeline.v1beta.LookUpPipelineAdminResponse\"\x00\x12\x8c\x01\n\x19ListPipelineReleasesAdmin\x12\x35.vdp.pipeline.v1beta.ListPipelineReleasesAdminRequest\x1a\x36.vdp.pipeline.v1beta.ListPipelineReleasesAdminResponse\"\x00\x1a\x39\x92\x41\x36\x12\x34Private methods to interact with Pipeline resources.B\xea\x01\n\x17\x63om.vdp.pipeline.v1betaB\x1bPipelinePrivateServiceProtoP\x01ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\xa2\x02\x03VPX\xaa\x02\x13Vdp.Pipeline.V1beta\xca\x02\x13Vdp\\Pipeline\\V1beta\xe2\x02\x1fVdp\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x15Vdp::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vdp.pipeline.v1beta.pipeline_private_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.vdp.pipeline.v1betaB\033PipelinePrivateServiceProtoP\001ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\242\002\003VPX\252\002\023Vdp.Pipeline.V1beta\312\002\023Vdp\\Pipeline\\V1beta\342\002\037Vdp\\Pipeline\\V1beta\\GPBMetadata\352\002\025Vdp::Pipeline::V1beta'
  _PIPELINEPRIVATESERVICE._options = None
  _PIPELINEPRIVATESERVICE._serialized_options = b'\222A6\0224Private methods to interact with Pipeline resources.'
  _globals['_PIPELINEPRIVATESERVICE']._serialized_start=160
  _globals['_PIPELINEPRIVATESERVICE']._serialized_end=631
# @@protoc_insertion_point(module_scope)
