# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/mgmt/v1beta/mgmt_public_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from core.mgmt.v1beta import metric_pb2 as core_dot_mgmt_dot_v1beta_dot_metric__pb2
from core.mgmt.v1beta import mgmt_pb2 as core_dot_mgmt_dot_v1beta_dot_mgmt__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*core/mgmt/v1beta/mgmt_public_service.proto\x12\x10\x63ore.mgmt.v1beta\x1a\x1d\x63ore/mgmt/v1beta/metric.proto\x1a\x1b\x63ore/mgmt/v1beta/mgmt.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/api/visibility.proto\x1a.protoc-gen-openapiv2/options/annotations.proto2\xec\x32\n\x11MgmtPublicService\x12\x94\x01\n\x08Liveness\x12!.core.mgmt.v1beta.LivenessRequest\x1a\".core.mgmt.v1beta.LivenessResponse\"A\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02+\x12\x12/v1beta/__livenessZ\x15\x12\x13/v1beta/health/mgmt\x12\x97\x01\n\tReadiness\x12\".core.mgmt.v1beta.ReadinessRequest\x1a#.core.mgmt.v1beta.ReadinessResponse\"A\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02+\x12\x13/v1beta/__readinessZ\x14\x12\x12/v1beta/ready/mgmt\x12\x94\x01\n\x14GetAuthenticatedUser\x12-.core.mgmt.v1beta.GetAuthenticatedUserRequest\x1a..core.mgmt.v1beta.GetAuthenticatedUserResponse\"\x1d\x92\x41\x06\n\x04User\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1beta/user\x12\xa0\x01\n\x16PatchAuthenticatedUser\x12/.core.mgmt.v1beta.PatchAuthenticatedUserRequest\x1a\x30.core.mgmt.v1beta.PatchAuthenticatedUserResponse\"#\x92\x41\x06\n\x04User\x82\xd3\xe4\x93\x02\x14\x32\x0c/v1beta/user:\x04user\x12t\n\tListUsers\x12\".core.mgmt.v1beta.ListUsersRequest\x1a#.core.mgmt.v1beta.ListUsersResponse\"\x1e\x92\x41\x06\n\x04User\x82\xd3\xe4\x93\x02\x0f\x12\r/v1beta/users\x12x\n\x07GetUser\x12 .core.mgmt.v1beta.GetUserRequest\x1a!.core.mgmt.v1beta.GetUserResponse\"(\x92\x41\x06\n\x04User\x82\xd3\xe4\x93\x02\x19\x12\x17/v1beta/users/{user_id}\x12\xad\x01\n\x12\x43reateOrganization\x12+.core.mgmt.v1beta.CreateOrganizationRequest\x1a,.core.mgmt.v1beta.CreateOrganizationResponse\"<\x92\x41\x0e\n\x0cOrganization\x82\xd3\xe4\x93\x02%\"\x15/v1beta/organizations:\x0corganization\x12\x9c\x01\n\x11ListOrganizations\x12*.core.mgmt.v1beta.ListOrganizationsRequest\x1a+.core.mgmt.v1beta.ListOrganizationsResponse\".\x92\x41\x0e\n\x0cOrganization\x82\xd3\xe4\x93\x02\x17\x12\x15/v1beta/organizations\x12\xa8\x01\n\x0fGetOrganization\x12(.core.mgmt.v1beta.GetOrganizationRequest\x1a).core.mgmt.v1beta.GetOrganizationResponse\"@\x92\x41\x0e\n\x0cOrganization\x82\xd3\xe4\x93\x02)\x12\'/v1beta/organizations/{organization_id}\x12\xbf\x01\n\x12UpdateOrganization\x12+.core.mgmt.v1beta.UpdateOrganizationRequest\x1a,.core.mgmt.v1beta.UpdateOrganizationResponse\"N\x92\x41\x0e\n\x0cOrganization\x82\xd3\xe4\x93\x02\x37\x32\'/v1beta/organizations/{organization_id}:\x0corganization\x12\xb1\x01\n\x12\x44\x65leteOrganization\x12+.core.mgmt.v1beta.DeleteOrganizationRequest\x1a,.core.mgmt.v1beta.DeleteOrganizationResponse\"@\x92\x41\x0e\n\x0cOrganization\x82\xd3\xe4\x93\x02)*\'/v1beta/organizations/{organization_id}\x12\xae\x01\n\x13ListUserMemberships\x12,.core.mgmt.v1beta.ListUserMembershipsRequest\x1a-.core.mgmt.v1beta.ListUserMembershipsResponse\":\x92\x41\x0c\n\nMembership\x82\xd3\xe4\x93\x02%\x12#/v1beta/users/{user_id}/memberships\x12\xba\x01\n\x11GetUserMembership\x12*.core.mgmt.v1beta.GetUserMembershipRequest\x1a+.core.mgmt.v1beta.GetUserMembershipResponse\"L\x92\x41\x0c\n\nMembership\x82\xd3\xe4\x93\x02\x37\x12\x35/v1beta/users/{user_id}/memberships/{organization_id}\x12\xcf\x01\n\x14UpdateUserMembership\x12-.core.mgmt.v1beta.UpdateUserMembershipRequest\x1a..core.mgmt.v1beta.UpdateUserMembershipResponse\"X\x92\x41\x0c\n\nMembership\x82\xd3\xe4\x93\x02\x43\x1a\x35/v1beta/users/{user_id}/memberships/{organization_id}:\nmembership\x12\xc3\x01\n\x14\x44\x65leteUserMembership\x12-.core.mgmt.v1beta.DeleteUserMembershipRequest\x1a..core.mgmt.v1beta.DeleteUserMembershipResponse\"L\x92\x41\x0c\n\nMembership\x82\xd3\xe4\x93\x02\x37*5/v1beta/users/{user_id}/memberships/{organization_id}\x12\xd6\x01\n\x1bListOrganizationMemberships\x12\x34.core.mgmt.v1beta.ListOrganizationMembershipsRequest\x1a\x35.core.mgmt.v1beta.ListOrganizationMembershipsResponse\"J\x92\x41\x0c\n\nMembership\x82\xd3\xe4\x93\x02\x35\x12\x33/v1beta/organizations/{organization_id}/memberships\x12\xda\x01\n\x19GetOrganizationMembership\x12\x32.core.mgmt.v1beta.GetOrganizationMembershipRequest\x1a\x33.core.mgmt.v1beta.GetOrganizationMembershipResponse\"T\x92\x41\x0c\n\nMembership\x82\xd3\xe4\x93\x02?\x12=/v1beta/organizations/{organization_id}/memberships/{user_id}\x12\xef\x01\n\x1cUpdateOrganizationMembership\x12\x35.core.mgmt.v1beta.UpdateOrganizationMembershipRequest\x1a\x36.core.mgmt.v1beta.UpdateOrganizationMembershipResponse\"`\x92\x41\x0c\n\nMembership\x82\xd3\xe4\x93\x02K\x1a=/v1beta/organizations/{organization_id}/memberships/{user_id}:\nmembership\x12\xe3\x01\n\x1c\x44\x65leteOrganizationMembership\x12\x35.core.mgmt.v1beta.DeleteOrganizationMembershipRequest\x1a\x36.core.mgmt.v1beta.DeleteOrganizationMembershipResponse\"T\x92\x41\x0c\n\nMembership\x82\xd3\xe4\x93\x02?*=/v1beta/organizations/{organization_id}/memberships/{user_id}\x12\xcd\x01\n GetAuthenticatedUserSubscription\x12\x39.core.mgmt.v1beta.GetAuthenticatedUserSubscriptionRequest\x1a:.core.mgmt.v1beta.GetAuthenticatedUserSubscriptionResponse\"2\x92\x41\x0e\n\x0cSubscription\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1beta/user/subscription\x12\xd9\x01\n\x1bGetOrganizationSubscription\x12\x34.core.mgmt.v1beta.GetOrganizationSubscriptionRequest\x1a\x35.core.mgmt.v1beta.GetOrganizationSubscriptionResponse\"M\x92\x41\x0e\n\x0cSubscription\x82\xd3\xe4\x93\x02\x36\x12\x34/v1beta/organizations/{organization_id}/subscription\x12\x83\x01\n\x0b\x43reateToken\x12$.core.mgmt.v1beta.CreateTokenRequest\x1a%.core.mgmt.v1beta.CreateTokenResponse\"\'\x92\x41\x07\n\x05Token\x82\xd3\xe4\x93\x02\x17\"\x0e/v1beta/tokens:\x05token\x12y\n\nListTokens\x12#.core.mgmt.v1beta.ListTokensRequest\x1a$.core.mgmt.v1beta.ListTokensResponse\" \x92\x41\x07\n\x05Token\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1beta/tokens\x12~\n\x08GetToken\x12!.core.mgmt.v1beta.GetTokenRequest\x1a\".core.mgmt.v1beta.GetTokenResponse\"+\x92\x41\x07\n\x05Token\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1beta/tokens/{token_id}\x12\x87\x01\n\x0b\x44\x65leteToken\x12$.core.mgmt.v1beta.DeleteTokenRequest\x1a%.core.mgmt.v1beta.DeleteTokenResponse\"+\x92\x41\x07\n\x05Token\x82\xd3\xe4\x93\x02\x1b*\x19/v1beta/tokens/{token_id}\x12\x8a\x01\n\rValidateToken\x12&.core.mgmt.v1beta.ValidateTokenRequest\x1a\'.core.mgmt.v1beta.ValidateTokenResponse\"(\x92\x41\x07\n\x05Token\x82\xd3\xe4\x93\x02\x18\"\x16/v1beta/validate_token\x12\xac\x01\n\x12GetRemainingCredit\x12+.core.mgmt.v1beta.GetRemainingCreditRequest\x1a,.core.mgmt.v1beta.GetRemainingCreditResponse\";\x92\x41\x08\n\x06\x43redit\x82\xd3\xe4\x93\x02*\x12(/v1beta/namespaces/{namespace_id}/credit\x12\x91\x01\n\x0e\x43heckNamespace\x12\'.core.mgmt.v1beta.CheckNamespaceRequest\x1a(.core.mgmt.v1beta.CheckNamespaceResponse\",\x92\x41\x07\n\x05Utils\x82\xd3\xe4\x93\x02\x1c\"\x17/v1beta/check-namespace:\x01*\x12\xcd\x01\n\x17GetPipelineTriggerCount\x12\x30.core.mgmt.v1beta.GetPipelineTriggerCountRequest\x1a\x31.core.mgmt.v1beta.GetPipelineTriggerCountResponse\"M\x92\x41\x08\n\x06Metric\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02,\x12*/v1beta/metrics/vdp/pipeline/trigger-count\x12\xd1\x01\n\x1fListPipelineTriggerTableRecords\x12\x38.core.mgmt.v1beta.ListPipelineTriggerTableRecordsRequest\x1a\x39.core.mgmt.v1beta.ListPipelineTriggerTableRecordsResponse\"9\x88\x02\x01\x92\x41\x08\n\x06Metric\x82\xd3\xe4\x93\x02%\x12#/v1beta/metrics/vdp/pipeline/tables\x12\xce\x01\n\x1fListPipelineTriggerChartRecords\x12\x38.core.mgmt.v1beta.ListPipelineTriggerChartRecordsRequest\x1a\x39.core.mgmt.v1beta.ListPipelineTriggerChartRecordsResponse\"6\x92\x41\x08\n\x06Metric\x82\xd3\xe4\x93\x02%\x12#/v1beta/metrics/vdp/pipeline/charts\x12\xce\x01\n!ListCreditConsumptionChartRecords\x12:.core.mgmt.v1beta.ListCreditConsumptionChartRecordsRequest\x1a;.core.mgmt.v1beta.ListCreditConsumptionChartRecordsResponse\"0\x92\x41\x08\n\x06Metric\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1beta/metrics/credit/charts\x12\x9c\x01\n\x0f\x41uthTokenIssuer\x12(.core.mgmt.v1beta.AuthTokenIssuerRequest\x1a).core.mgmt.v1beta.AuthTokenIssuerResponse\"4\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x1e\"\x19/v1beta/auth/token_issuer:\x01*\x12\x80\x01\n\tAuthLogin\x12\".core.mgmt.v1beta.AuthLoginRequest\x1a#.core.mgmt.v1beta.AuthLoginResponse\"*\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x14\"\x12/v1beta/auth/login\x12\x84\x01\n\nAuthLogout\x12#.core.mgmt.v1beta.AuthLogoutRequest\x1a$.core.mgmt.v1beta.AuthLogoutResponse\"+\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x15\"\x13/v1beta/auth/logout\x12\xa8\x01\n\x12\x41uthChangePassword\x12+.core.mgmt.v1beta.AuthChangePasswordRequest\x1a,.core.mgmt.v1beta.AuthChangePasswordResponse\"7\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02!\"\x1c/v1beta/auth/change_password:\x01*\x12\xba\x01\n\x17\x41uthValidateAccessToken\x12\x30.core.mgmt.v1beta.AuthValidateAccessTokenRequest\x1a\x31.core.mgmt.v1beta.AuthValidateAccessTokenResponse\":\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02$\"\"/v1beta/auth/validate_access_token\x1a\x1a\x92\x41\x17\x12\x15Public Core endpointsB\xcf\x01\n\x14\x63om.core.mgmt.v1betaB\x16MgmtPublicServiceProtoP\x01Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\xa2\x02\x03\x43MX\xaa\x02\x10\x43ore.Mgmt.V1beta\xca\x02\x10\x43ore\\Mgmt\\V1beta\xe2\x02\x1c\x43ore\\Mgmt\\V1beta\\GPBMetadata\xea\x02\x12\x43ore::Mgmt::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core.mgmt.v1beta.mgmt_public_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.core.mgmt.v1betaB\026MgmtPublicServiceProtoP\001Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\242\002\003CMX\252\002\020Core.Mgmt.V1beta\312\002\020Core\\Mgmt\\V1beta\342\002\034Core\\Mgmt\\V1beta\\GPBMetadata\352\002\022Core::Mgmt::V1beta'
  _MGMTPUBLICSERVICE._options = None
  _MGMTPUBLICSERVICE._serialized_options = b'\222A\027\022\025Public Core endpoints'
  _MGMTPUBLICSERVICE.methods_by_name['Liveness']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['Liveness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002+\022\022/v1beta/__livenessZ\025\022\023/v1beta/health/mgmt'
  _MGMTPUBLICSERVICE.methods_by_name['Readiness']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['Readiness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002+\022\023/v1beta/__readinessZ\024\022\022/v1beta/ready/mgmt'
  _MGMTPUBLICSERVICE.methods_by_name['GetAuthenticatedUser']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetAuthenticatedUser']._serialized_options = b'\222A\006\n\004User\202\323\344\223\002\016\022\014/v1beta/user'
  _MGMTPUBLICSERVICE.methods_by_name['PatchAuthenticatedUser']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['PatchAuthenticatedUser']._serialized_options = b'\222A\006\n\004User\202\323\344\223\002\0242\014/v1beta/user:\004user'
  _MGMTPUBLICSERVICE.methods_by_name['ListUsers']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListUsers']._serialized_options = b'\222A\006\n\004User\202\323\344\223\002\017\022\r/v1beta/users'
  _MGMTPUBLICSERVICE.methods_by_name['GetUser']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetUser']._serialized_options = b'\222A\006\n\004User\202\323\344\223\002\031\022\027/v1beta/users/{user_id}'
  _MGMTPUBLICSERVICE.methods_by_name['CreateOrganization']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['CreateOrganization']._serialized_options = b'\222A\016\n\014Organization\202\323\344\223\002%\"\025/v1beta/organizations:\014organization'
  _MGMTPUBLICSERVICE.methods_by_name['ListOrganizations']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListOrganizations']._serialized_options = b'\222A\016\n\014Organization\202\323\344\223\002\027\022\025/v1beta/organizations'
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganization']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganization']._serialized_options = b'\222A\016\n\014Organization\202\323\344\223\002)\022\'/v1beta/organizations/{organization_id}'
  _MGMTPUBLICSERVICE.methods_by_name['UpdateOrganization']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['UpdateOrganization']._serialized_options = b'\222A\016\n\014Organization\202\323\344\223\00272\'/v1beta/organizations/{organization_id}:\014organization'
  _MGMTPUBLICSERVICE.methods_by_name['DeleteOrganization']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['DeleteOrganization']._serialized_options = b'\222A\016\n\014Organization\202\323\344\223\002)*\'/v1beta/organizations/{organization_id}'
  _MGMTPUBLICSERVICE.methods_by_name['ListUserMemberships']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListUserMemberships']._serialized_options = b'\222A\014\n\nMembership\202\323\344\223\002%\022#/v1beta/users/{user_id}/memberships'
  _MGMTPUBLICSERVICE.methods_by_name['GetUserMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetUserMembership']._serialized_options = b'\222A\014\n\nMembership\202\323\344\223\0027\0225/v1beta/users/{user_id}/memberships/{organization_id}'
  _MGMTPUBLICSERVICE.methods_by_name['UpdateUserMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['UpdateUserMembership']._serialized_options = b'\222A\014\n\nMembership\202\323\344\223\002C\0325/v1beta/users/{user_id}/memberships/{organization_id}:\nmembership'
  _MGMTPUBLICSERVICE.methods_by_name['DeleteUserMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['DeleteUserMembership']._serialized_options = b'\222A\014\n\nMembership\202\323\344\223\0027*5/v1beta/users/{user_id}/memberships/{organization_id}'
  _MGMTPUBLICSERVICE.methods_by_name['ListOrganizationMemberships']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListOrganizationMemberships']._serialized_options = b'\222A\014\n\nMembership\202\323\344\223\0025\0223/v1beta/organizations/{organization_id}/memberships'
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganizationMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganizationMembership']._serialized_options = b'\222A\014\n\nMembership\202\323\344\223\002?\022=/v1beta/organizations/{organization_id}/memberships/{user_id}'
  _MGMTPUBLICSERVICE.methods_by_name['UpdateOrganizationMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['UpdateOrganizationMembership']._serialized_options = b'\222A\014\n\nMembership\202\323\344\223\002K\032=/v1beta/organizations/{organization_id}/memberships/{user_id}:\nmembership'
  _MGMTPUBLICSERVICE.methods_by_name['DeleteOrganizationMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['DeleteOrganizationMembership']._serialized_options = b'\222A\014\n\nMembership\202\323\344\223\002?*=/v1beta/organizations/{organization_id}/memberships/{user_id}'
  _MGMTPUBLICSERVICE.methods_by_name['GetAuthenticatedUserSubscription']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetAuthenticatedUserSubscription']._serialized_options = b'\222A\016\n\014Subscription\202\323\344\223\002\033\022\031/v1beta/user/subscription'
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganizationSubscription']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganizationSubscription']._serialized_options = b'\222A\016\n\014Subscription\202\323\344\223\0026\0224/v1beta/organizations/{organization_id}/subscription'
  _MGMTPUBLICSERVICE.methods_by_name['CreateToken']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['CreateToken']._serialized_options = b'\222A\007\n\005Token\202\323\344\223\002\027\"\016/v1beta/tokens:\005token'
  _MGMTPUBLICSERVICE.methods_by_name['ListTokens']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListTokens']._serialized_options = b'\222A\007\n\005Token\202\323\344\223\002\020\022\016/v1beta/tokens'
  _MGMTPUBLICSERVICE.methods_by_name['GetToken']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetToken']._serialized_options = b'\222A\007\n\005Token\202\323\344\223\002\033\022\031/v1beta/tokens/{token_id}'
  _MGMTPUBLICSERVICE.methods_by_name['DeleteToken']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['DeleteToken']._serialized_options = b'\222A\007\n\005Token\202\323\344\223\002\033*\031/v1beta/tokens/{token_id}'
  _MGMTPUBLICSERVICE.methods_by_name['ValidateToken']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ValidateToken']._serialized_options = b'\222A\007\n\005Token\202\323\344\223\002\030\"\026/v1beta/validate_token'
  _MGMTPUBLICSERVICE.methods_by_name['GetRemainingCredit']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetRemainingCredit']._serialized_options = b'\222A\010\n\006Credit\202\323\344\223\002*\022(/v1beta/namespaces/{namespace_id}/credit'
  _MGMTPUBLICSERVICE.methods_by_name['CheckNamespace']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['CheckNamespace']._serialized_options = b'\222A\007\n\005Utils\202\323\344\223\002\034\"\027/v1beta/check-namespace:\001*'
  _MGMTPUBLICSERVICE.methods_by_name['GetPipelineTriggerCount']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetPipelineTriggerCount']._serialized_options = b'\222A\010\n\006Metric\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002,\022*/v1beta/metrics/vdp/pipeline/trigger-count'
  _MGMTPUBLICSERVICE.methods_by_name['ListPipelineTriggerTableRecords']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListPipelineTriggerTableRecords']._serialized_options = b'\210\002\001\222A\010\n\006Metric\202\323\344\223\002%\022#/v1beta/metrics/vdp/pipeline/tables'
  _MGMTPUBLICSERVICE.methods_by_name['ListPipelineTriggerChartRecords']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListPipelineTriggerChartRecords']._serialized_options = b'\222A\010\n\006Metric\202\323\344\223\002%\022#/v1beta/metrics/vdp/pipeline/charts'
  _MGMTPUBLICSERVICE.methods_by_name['ListCreditConsumptionChartRecords']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListCreditConsumptionChartRecords']._serialized_options = b'\222A\010\n\006Metric\202\323\344\223\002\037\022\035/v1beta/metrics/credit/charts'
  _MGMTPUBLICSERVICE.methods_by_name['AuthTokenIssuer']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['AuthTokenIssuer']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\036\"\031/v1beta/auth/token_issuer:\001*'
  _MGMTPUBLICSERVICE.methods_by_name['AuthLogin']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['AuthLogin']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\024\"\022/v1beta/auth/login'
  _MGMTPUBLICSERVICE.methods_by_name['AuthLogout']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['AuthLogout']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\025\"\023/v1beta/auth/logout'
  _MGMTPUBLICSERVICE.methods_by_name['AuthChangePassword']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['AuthChangePassword']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002!\"\034/v1beta/auth/change_password:\001*'
  _MGMTPUBLICSERVICE.methods_by_name['AuthValidateAccessToken']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['AuthValidateAccessToken']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002$\"\"/v1beta/auth/validate_access_token'
  _globals['_MGMTPUBLICSERVICE']._serialized_start=232
  _globals['_MGMTPUBLICSERVICE']._serialized_end=6740
# @@protoc_insertion_point(module_scope)
