# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/model/v1alpha/task_classification.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-model/model/v1alpha/task_classification.proto\x12\x13model.model.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\"a\n\x13\x43lassificationInput\x12\x1d\n\timage_url\x18\x01 \x01(\tH\x00R\x08imageUrl\x12#\n\x0cimage_base64\x18\x02 \x01(\tH\x00R\x0bimageBase64B\x06\n\x04type\"d\n\x19\x43lassificationInputStream\x12\'\n\x0c\x66ile_lengths\x18\x01 \x03(\rB\x04\xe2\x41\x01\x02R\x0b\x66ileLengths\x12\x1e\n\x07\x63ontent\x18\x02 \x01(\x0c\x42\x04\xe2\x41\x01\x02R\x07\x63ontent\"T\n\x14\x43lassificationOutput\x12 \n\x08\x63\x61tegory\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x08\x63\x61tegory\x12\x1a\n\x05score\x18\x02 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x05scoreB\xe4\x01\n\x17\x63om.model.model.v1alphaB\x17TaskClassificationProtoP\x01ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\xa2\x02\x03MMX\xaa\x02\x13Model.Model.V1alpha\xca\x02\x13Model\\Model\\V1alpha\xe2\x02\x1fModel\\Model\\V1alpha\\GPBMetadata\xea\x02\x15Model::Model::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.model.v1alpha.task_classification_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.model.model.v1alphaB\027TaskClassificationProtoP\001ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\242\002\003MMX\252\002\023Model.Model.V1alpha\312\002\023Model\\Model\\V1alpha\342\002\037Model\\Model\\V1alpha\\GPBMetadata\352\002\025Model::Model::V1alpha'
  _CLASSIFICATIONINPUTSTREAM.fields_by_name['file_lengths']._options = None
  _CLASSIFICATIONINPUTSTREAM.fields_by_name['file_lengths']._serialized_options = b'\342A\001\002'
  _CLASSIFICATIONINPUTSTREAM.fields_by_name['content']._options = None
  _CLASSIFICATIONINPUTSTREAM.fields_by_name['content']._serialized_options = b'\342A\001\002'
  _CLASSIFICATIONOUTPUT.fields_by_name['category']._options = None
  _CLASSIFICATIONOUTPUT.fields_by_name['category']._serialized_options = b'\342A\001\003'
  _CLASSIFICATIONOUTPUT.fields_by_name['score']._options = None
  _CLASSIFICATIONOUTPUT.fields_by_name['score']._serialized_options = b'\342A\001\003'
  _globals['_CLASSIFICATIONINPUT']._serialized_start=103
  _globals['_CLASSIFICATIONINPUT']._serialized_end=200
  _globals['_CLASSIFICATIONINPUTSTREAM']._serialized_start=202
  _globals['_CLASSIFICATIONINPUTSTREAM']._serialized_end=302
  _globals['_CLASSIFICATIONOUTPUT']._serialized_start=304
  _globals['_CLASSIFICATIONOUTPUT']._serialized_end=388
# @@protoc_insertion_point(module_scope)
